@@ -3,10 +3,10 @@
       implicit none
 #include "Zcode.h"
 #include "Zptcl.h"
-      record /ptcl/pj
+      type(ptcl)::pj
       integer:: ita, itz, Nsp, A, Z
       integer,parameter::npmax=500
-      record /ptcl/x(npmax)
+      type(ptcl)::x(npmax)
       
       integer:: i, np, j
 
