@@ -9,9 +9,16 @@
       integer  KODFRAG                  
       COMMON /CKFRAG/ KODFRAG                  
 
+      INTEGER NCALL, NDEBUG, LUN
+      COMMON /S_DEBUG/ NCALL, NDEBUG, LUN
+
+      
 
       KODFRAG =0  ! complex fragmentation by Abrasion-ablation model
-      LDIFF = 0   ! mix diff and non-diff
+      LDIFF = 0       ! mix diff and non-diff
+
+      LUN = 0         ! logical dev. # for (error) message  from sibyll
+! sibyll default is 7.
       call SIBYLL_INI
       call SIGMA_INI   ! p-/pi-/K-Air  sigma and mfp
                    ! 
@@ -22,25 +29,27 @@
 !           for AA' col.
 !       call SIGNUC_INI(...) !  this is almost useless
 !                    so we make cgetAAXsSib for each
-!                    AA' col.
-
+!     AA' col.
       IDB(4:12) = -IDB(4:12)
 
 !            short life particle decay is managed by us
-!          
+!
 !       same for eta
       IDB(23)  = -IDB(23)
 !       same for  SIGMA, XI, LAMBDA
 !      do  i = 34, 39
       IDB(34:36) = -IDB(34:36)
       IDB(39) = -IDB(39)
-!/////////
-!      IDB(34) = abs(IDB(34))
-!///////
+      
+!     decay control: can force not to decay for
+!        some of short life ptcls s
+!!!      call csibSetStblPtcl
       end
 !     ****************
       subroutine  csibyllevent(pj, ia, iz, a, ntp)
+      use modXsecMedia
       implicit none
+#include "Zmanager.h"      
 #include "Zcode.h"
 #include "Zptcl.h"
 #include "Zmass.h"
@@ -68,18 +77,25 @@
 
 
 !       call csibyllIniEvent   ! no need at presnt
-      call ccoscode2sibyll(pj, icp)  ! get sibyll code of pj
-      iat =  ia !  target mass number
+      call ccoscode2sibyll(pj, icp) ! get sibyll code of pj
+      iat =  ia                 !  target mass number
+!!        we don't use A=0 for Sibyll Air medium 
+!!!      if( CosOrEpi /= 'gencol') then
+!!         if( media(mediumNo)%name == "Air") then
+!!            iat = 0
+!!         endif
+!!      endif   
       if(pj%code .eq. kgnuc) then
          E0 = pj%fm%p(4)/pj%subcode !  GeV/n in Lab
-         Ecm = sqrt( ( E0 +masp )*2*masp )  ! nn system
+         Ecm = sqrt( ( E0 +masp )*2*masp ) ! nn system
       else
-         if( pj%code == klambda ) then
-            icp = 14 ! n
-         endif
+!         if( pj%code == klambda ) then   ! upto v8.02
+!            icp = 14            ! n
+!         endif
          E0 = pj%fm%p(4)
          Ecm = sqrt( E0*2*masp + pj%mass**2 + masp**2)
       endif
+
       sqs = Ecm
       g = (E0 + masp)/Ecm  ! cms gamma factor  !=sqs/2/mp for pi/K
       beta = sqrt( (g-1.d0) * (g + 1.d0)) /g
@@ -113,6 +129,7 @@
       INTEGER          LLA,NPA
       COMMON /S_PLNUC/ NPA, PA(5,40000), LLA(40000)
 
+
       end      subroutine csibyllIniEvent
 
 
