@@ -120,55 +120,40 @@
        integer massn
        character*70  msg
        data 
-     * mass(kphoton, -1)/x/, mass(kphoton, 0)/0./,
-     * mass(kphoton, 1)/x/,
-     * mass(kelec,-1)/masele/,mass(kelec, 0)/x/,
-     * mass(kelec, 1)/masele/,
-     * mass(kmuon, -1)/masmu/,mass(kmuon, 0)/x/,
-     * mass(kmuon, 1)/masmu/, 
-     * mass(kpion, -1)/maspic/,mass(kpion, 0)/maspi0/,
-     * mass(kpion, 1)/maspic/
+     * mass(kphoton, :)/x, 0., x/,
+     * mass(kelec,:)/masele,x, masele/,
+     * mass(kmuon, :)/masmu,x,masmu/, 
+     * mass(kpion, :)/maspic, maspi0, maspic/
        data
-     * mass(kkaon, -1)/maskc/,mass(kkaon, 0)/mask0/,
-     * mass(kkaon, 1)/maskc/,
-     * mass(knuc, -1)/masp/, mass(knuc, 0)/masn/, 
-     * mass(knuc, 1)/masp/,
-     * mass(kneue, -1)/x/, mass(kneue, 0)/0./, 
-     * mass(kneue, 1)/x/,
-     * mass(kneumu,-1)/x/, mass(kneumu, 0)/0./, 
-     * mass(kneumu, 1)/x/,
-     * mass(knnb,  -1)/x/, mass(knnb, 0)/masnnb/,
-     * mass(knnb, 1)/x/
+     * mass(kkaon, :)/maskc, mask0, maskc/,
+     * mass(knuc, :)/masp, masn, masp/,
+     * mass(kneue, :)/x, 0., x/,
+     * mass(kneumu,:)/x, 0., x/,
+     * mass(kneumu,:)/x, 0., x/,
+     * mass(knnb,  :)/x, masnnb, x/
        data
-     * mass(kddb, -1)/x/, mass(kddb, 0)/masddb/,
-     * mass(kddb, 1)/x/,
-     * mass(kdmes, -1)/masd/, mass(kdmes, 0)/masd/, 
-     * mass(kdmes, 1)/masd/,
-     * mass(krho, -1)/masrho/,  mass(krho, 0)/masrho/,
-     * mass(krho, 1)/masrho/,
-     * mass(komega, -1)/x/,mass(komega, 0)/masomg/,
-     * mass(komega,1)/x/,
-     * mass(kphi, -1)/x/, mass(kphi, 0)/masphi/, 
-     * mass(kphi, 1)/x/,
-     * mass(keta, -1)/x/, mass(keta, 0)/maseta/,
-     * mass(keta, 1)/x/ 
-       data
-     * mass(ksigma, -1)/massigmam/, mass(ksigma, 0)/massigma0/,
-     * mass(ksigma, 1) /massigmap/,
-     * mass(kgzai, -1) /masgzaim/, mass(kgzai, 0)/masgzai0/,
-     * mass(kgzai, 1) /masgzaim/,
-     * mass(klambda, 0)/maslambda/, mass(klambda, -1)/x/,
-     * mass(klambda, 1)/x/,
-     * mass(klambdac,-1)/maslambdac/, mass(klambdac, 0)/x/,
-     * mass(klambdac, 1)/maslambdac/,
-     * mass(krare, -1)/0./, mass(krare,0)/0./, mass(krare,1)/0./,
-     * mass(kgnuc, -1)/x/, mass(kgnuc,0)/x/, mass(kgnuc,1)/x/
-       data 
-     * mass(kbomega, -1)/masbomega/, mass(kbomega,0)/x/,
-     * mass(kbomega, 1) /masbomega/
-!
+     * mass(kddb, :)/x,masddb,x/,
+     * mass(kdmes,:)/masd, masd, masd/
+     * mass(krho, :)/masrho,  masrho, masrho/,
+     * mass(komega,:)/x,masomg, x/ 
+     * mass(kphi,:)/x, masphi, x/
+     * mass(keta, :)/x, maseta, x/
+     * mass(ketap, :)/x, masetap, x/
 
- 
+       data
+     * mass(ksigma, :)/massigmam, massigma0, massigmap/,
+     * mass(kgzai,  :)/masgzaim, masgzai0, masgzaim/,
+     * mass(klambda,:)/x, maslambda,x/,
+     * mass(klambdac,:)/maslambdac, x, maslambdac/,
+     * mass(krare, :)/0., 0., 0./,
+     * mass(kgnuc, :)/x, x, x/
+       data 
+     * mass(kbomega, :)/masbomega, x, masbomega/,
+     *      mass(kds,:) /masds, x, masds/,
+     *      mass(kXic,:)/masXic, masXic0, masXic/,
+     *      mass(ktau,:)/mastau, x, mastau/,        
+     *      mass(komeC0,:)/x, masomC0, x/
+     *      mass(kDelta,:)/masDelta,masDelta, masDelta/ 
 !       if(code .ge. kdeut .and. code .le. khvymax) then
        if(code .ge. kalfa .and. code .le. khvymax) then
 !                  get mass number
@@ -395,9 +380,9 @@
          data ida(ksigma)/'sigma'/, ida(klambda)/'lambda'/,
      *   ida(kgzai)/'gzai'/, ida(klambdac)/'lambdac'/,
      *   ida(kbomega)/'Omega'/
-!
-
-
+         data ida(ktau)/'tau'/, ida(kneutau)/'neu_tau'/
+         data ida(kds)/'Ds'/, ida(kXic)/'Xic'/
+         data ida(komeC0)/'OmegaC0'/ 
          if(code .ge. 1 .and. code .le. klast)then
               id = ida(code)
          else
