@@ -11,7 +11,8 @@
       real(8)::u
       integer kfabs
       kfabs = abs(kf)
-      if( kfabs == 311 ) then  ! K0 : 50% K0s; 50 % K0L
+!          special treatment for K0
+      if( kfabs == kfk0 ) then  ! K0 : 50% K0s; 50 % K0L
          call rndc(u)
          if(u < 0.5 ) then
             kfabs = kfk0s
@@ -19,6 +20,7 @@
             kfabs = kfk0l
          endif
       endif
+!           
       if(kfabs .eq. kfpion) then
          code = kpion
          subcode = sign(1, -kf)
@@ -71,6 +73,10 @@
          code = kelec
          subcode = sign(1, -kf)
          chg = sign(1, -kf)
+      elseif( kf .eq.  kfphoton ) then
+         code = kphoton
+         subcode = 0
+         chg = 0
       elseif(kfabs .eq. kfmuon) then
          code = kmuon
          subcode = sign(1, -kf)
@@ -83,10 +89,6 @@
         code = kneumu
         subcode =sign(1, -kf)
         chg = 0
-      elseif( kf .eq.  kfphoton ) then
-         code = kphoton
-         subcode = 0
-         chg = 0
       elseif(kfabs .eq. kfdmes) then
          code = kdmes
          subcode = sign(1, -kf)
@@ -99,6 +101,35 @@
          code = klambda
          subcode = sign(1, -kf)
          chg = 0
+      elseif( kfabs .ge. 1000000020 .and. kfabs .le. 1000922350 ) then ! 2n system
+!           nucleus is  10LZZZAAAI where L=0 (if not containing strangeness)
+!           ZZZ is 3 digits of charge, AAA 3digits of mass no. I=0 for
+!           gound state; so for our case, 1000010020 is minimum for deuteron
+!           and 1000922350 is max for U(235)
+         if(kf .lt. 0) then
+            write(0,*) ' anti nuclues is not yet supported '
+            code = krare
+         else
+            code=kgnuc
+            subcode =( (kfabs/10)*10-(kfabs/10000)*10000 )/10
+            chg =( (kfabs/10000)*10000 - (kfabs/1000000)*1000000 )
+     *        /10000     
+            if( kfabs < 1000010020 ) then  ! charge 0               
+               code = krare
+            endif
+         endif
+      elseif(kfabs == kfDelta0) then
+         code = kDelta
+         subcode = -1
+         chg =0
+      elseif(kfabs == kfDeltap) then
+         code = kDelta
+         subcode = -1
+         chg = 1
+      elseif(kfabs == kfDeltam) then
+         code = kDelta
+         subcode = 1
+         chg = -1
       elseif(kfabs .eq. kfsigma0) then
          code = ksigma
          subcode = sign(1, -kf)
@@ -127,60 +158,69 @@
          code = kbomega
          subcode = sign(1, -kf)
          chg =  sign(1, -kf)
-      elseif(kfabs .eq. 16) then
-         code = krare    !  tau neutrion. neglect 
-      elseif(kfabs .eq. 113) then  ! rho
+      elseif(kfabs .eq. kftau ) then
+         code = ktau            
+         subcode = sign(1, -kf)
+         chg = sign(1, -kf)
+      elseif( kfabs == kfneutau )then
+         code = kfneutau
+         subcode = sign(1,-kf)
+         chg= 0
+      elseif(kfabs .eq. kfrho) then  ! rho
          code = krho
          subcode = 0
          chg = 0
-      elseif(kfabs .eq. 223) then   ! omega
+      elseif(kfabs == kfrhoc) then
+         code = krho
+         subcode = sign(1, -kf)
+         chg = sign(1, kf)
+      elseif(kfabs .eq. kfomega) then   ! omega
          code = komega
          subcode = 0
          chg = 0
-      elseif( kfabs .eq. 333 ) then  ! phi
+      elseif( kfabs .eq. kfphi ) then  ! phi
          code = kphi
          subcode = 0
          chg = 0
-!      elseif( kfabs .ge. 1000010020 .and. kfabs .le. 1000922350 ) then  ! 2013/4/12
-      elseif( kfabs .ge. 1000000020 .and. kfabs .le. 1000922350 ) then  ! 2n system
-!           nucleus is  10LZZZAAAI where L=0 (if not containing strangeness)
-!           ZZZ is 3 digits of charge, AAA 3digits of mass no. I=0 for
-!           gound state; so for our case, 1000010020 is minimum for deuteron
-!           and 1000922350 is max for U(235)
-         if(kf .lt. 0) then
-            write(0,*) ' anti nuclues is not yet supported '
-            code = krare
-         else
-            code=kgnuc
-            subcode =( (kfabs/10)*10-(kfabs/10000)*10000 )/10
-            chg =( (kfabs/10000)*10000 - (kfabs/1000000)*1000000 )
-     *        /10000     
-            if( kfabs < 1000010020 ) then  ! charge 0               
-               code = krare
-            endif
-         endif
+      elseif( kfabs == kfds ) then ! Ds
+         code = kds
+         chg = sign(1, kf )
+         subcode = sign(1,-kf)
+      elseif( kfabs == kfXic ) then
+         code = kXic
+         chg = sign(1,kf)
+         subcode = sign(1,-kf)
+      elseif( kfabs == kfXic0 ) then
+         code = kXic0
+         chg =0
+         subcode =sign(1,-kf)
+      elseif( kfabs == kfomeC0 ) then
+         code = komeC0
+         chg = 0
+         subcode =  sign(1,-kf)
+      elseif( kfabs == kfetap ) then
+         code = ketap
+         chg = 0
+         subcode = 0
       else
          code = krare
       endif
       if( code == krare ) then
          write(msg, *) 'not implemented kf code=', kf
          call cerrorMsg(msg, 1)
-         call cerrorMsg('we may neglect this particle',1)
+         call cerrorMsg('we neglect this particle',1)
       endif
       end
 
       subroutine ccos2kf(code, subcode, chg, kf)
-!         cosmos code to kf code
-!         only hadronic interacting particles are treaed.
+!         cosmos code to kf code; 
       implicit none
 #include "Zcode.h"
 #include "Zkfcode.h"
-      integer code, subcode, chg  ! input
-      integer kf   ! output
-
-      character*80 msg
-
-
+      integer,intent(in):: code, subcode, chg ! cosmos code but not integer*2
+      integer,intent(out):: kf  !  0 means code is not in PDG
+!                              (say, kEdepo ...)          
+      character*80 msg      
       if(code .eq. kelec) then
          kf = sign(kfelec, -chg)
       elseif(code .eq. kphoton) then
@@ -221,6 +261,29 @@
          endif
       elseif(code .eq. klambda) then
          kf = sign(kflambda, -subcode)
+      elseif(code .eq. kgnuc ) then
+         kf = 1000000000 + abs(chg)*10000 + subcode*10
+         kf = sign(kf, chg)
+      elseif( code == keta ) then
+         kf = kfeta
+      elseif( code == krho ) then
+         if( chg == 0) then
+            kf = kfrho
+         else
+            kf = sign(kfrhoc, chg)
+         endif
+      elseif( code == kDelta ) then
+         if( chg == 0 ) then
+            kf = kfDelta0
+         elseif( chg == 1 ) then
+            kf = kfDeltap
+         else
+            kf = kfDeltam
+         endif
+      elseif ( code == komega ) then
+         kf = kfomega
+      elseif( code == kphi ) then
+         kf = kfphi
       elseif(code .eq. ksigma) then
          if(chg .eq. 1) then
             kf = sign(kfsigmap, -subcode)
@@ -236,27 +299,32 @@
             kf = sign(kfgzai, -chg)
          endif
       elseif(code .eq. klambdac) then
-         kf =sign(kflambdac, -subcode)
+         kf =sign(kflambdac, chg)
       elseif(code .eq. kbomega ) then
          kf = sign(kfbomega, -chg)
-      elseif(code .eq. kgnuc ) then
-         kf = 1000000000 + abs(chg)*10000 + subcode*10
-         kf = sign(kf, chg)
-      elseif( code == keta ) then
-         kf = kfeta
-      elseif( code == krho ) then
-         kf = kfrho
-      elseif ( code == komega ) then
-         kf = kfomega
-      elseif( code == kphi ) then
-         kf = kfphi
+      elseif( code == kds ) then
+         kf = sign(kfds, -chg)
+      elseif( code ==  kXic ) then
+         kf = sign(kfXic, -chg)
+      elseif( code == komeC0 ) then
+         kf = sign(kfomeC0, -subcode)
+      elseif( code == ktau ) then
+         kf = sign(kftau, -subcode)
+      elseif( code == kneutau) then
+         kf = sign(kfneutau, -subcode)
+      elseif( code == ketap ) then
+         kf = kfetap
+      elseif( code <= 0 )then
+         kf = 0
       else
          write(msg, *) 'code, subcode, chg to  ccos2kf=', 
      &      code, subcode, chg  
          call cerrorMsg(msg, 1)
          call cerrorMsg(' cannot be converted to kf code',1)
-         kf=10000
+         kf=0
       endif
+
+
       end
       
       subroutine ckf2cosB(kf, p)
@@ -275,7 +343,7 @@
       subroutine ccos2kfB(p, kf)  ! inverse of ckf2cosB
       implicit none
 #include "Zptcl.h"
-      type(ptcl):: p  ! input; p%code, p%subcode and p%charge 
+      type(ptcl),intent(in):: p  ! input; p%code, p%subcode and p%charge 
       integer,intent(out):: kf  ! pdg code for p%code...
 
       integer:: code, subcode, charge
