@@ -8,7 +8,7 @@
 #include "Zevhnv.h"
 #include "Zcode.h"
 ! #include "Zmass.h"
-      record /ptcl/ pj  ! input.  hadronic projectile particle
+      type(ptcl):: pj  ! input.  hadronic projectile particle
                         !  which is  going to make the collision
                 ! fixed by epfixProc or cfixProc 
        ! **** Must not be called for other interactions ***** 
@@ -23,18 +23,18 @@
       icon = 0
       select case(ActiveMdl)
       case('phits')
-         if(  pj.code == kpion .and. pj.charge == 0) then
+         if(  pj%code == kpion .and. pj%charge == 0) then
             icon = -1
 !         elseif( pj.code == kkaon .and. pj.charge == 0 ) then
-         elseif( pj.code == kkaon ) then ! from v 7.633  
+         elseif( pj%code == kkaon ) then ! from v 7.633  
                            ! at cfixModel, phits might be
                            ! already not assigned
             icon  = -1
-         elseif( pj.code >=  klambda .or. pj.code == kdmes ) then
+         elseif( pj%code >=  klambda .or. pj%code == kdmes ) then
             icon = -1
          endif
       case('jam') 
-         if(  pj.code == kpion .and. pj.charge == 0) then
+         if(  pj%code == kpion .and. pj%charge == 0) then
             icon = -1   ! revived v9.153
 
 !         elseif( pj.code == kkaon .and. pj.charge == 0 ) then
@@ -57,17 +57,17 @@
 !            icon = -1
 !         elseif( pj.code == kkaon .and. pj.charge == 0 ) then
 !            icon  = -1
-         if( pj.code >=  klambda .or. pj.code == kdmes ) then
+         if( pj%code >=  klambda .or. pj%code == kdmes ) then
             icon = -1
          endif
 
       case('epos')    
 !         if(  pj.code == kdmes .or. pj.code == 'kgzai') then
-         if(  pj.code == kdmes ) then
+         if(  pj%code == kdmes ) then
             icon = -1
          endif
       case('sibyll') 
-         if( pj.code >  klambda .or. pj.code == kdmes ) then
+         if( pj%code >  klambda .or. pj%code == kdmes ) then
             icon = -1
          endif
       case('fritiof1.6')         
@@ -76,13 +76,13 @@
 !            icon = -1
 !         elseif( pj.code == kkaon .and. pj.charge == 0 ) then
 !            icon  = -1
-         if( pj.code >=  klambda .or. pj.code == kdmes ) then
+         if( pj%code >=  klambda .or. pj%code == kdmes ) then
             icon = -1
          endif
       case('dpmjet3')
-         if( pj.code == keta ) then
+         if( pj%code == keta ) then
             icon = -1
-         elseif( pj.code == kgzai .and. pj.fm.p(4)<= 9.d0)  then
+         elseif( pj%code == kgzai .and. pj%fm%p(4)<= 9.d0)  then
             icon = -1
          endif
       end select
