@@ -1,5 +1,5 @@
-c     ctotx: x A collsion total cross section 
-c      
+!     ctotx: x A collsion total cross section 
+!      
       module modcosXsec
       logical,save:: nIsDiff=.false.
       end module modcosXsec
@@ -9,16 +9,16 @@ c
 #include "Zcode.h"
 #include "Zmass.h"
 #include "Zevhnp.h"
-      record /ptcl/pjin   !input projectile particle
+      type(ptcl)::pjin   !input projectile particle
       real(8),intent(in)::  Ain          ! input. effective target mass number
       real(8),intent(out):: xs          ! output. in mb. total xsection. 
-c           ctotx0 gives small Xs so we renormalize by
-c           using cPDGsigmaTotpA(A) at @200 GeV 
+!           ctotx0 gives small Xs so we renormalize by
+!           using cPDGsigmaTotpA(A) at @200 GeV 
       real(8),intent(in):: Zin
       real(8):: cPDGsigmaTotpA
 
-      record /ptcl/ pj
-      record /ptcl/ proton
+      type(ptcl):: pj
+      type(ptcl):: proton
       save proton
       real(8),save:: xst
       logical,save::first=.true. 
@@ -38,11 +38,11 @@ c           using cPDGsigmaTotpA(A) at @200 GeV
  20   continue
       pj = pjin
       A = Ain      
-      if( pjin.code == kgnuc .and. Ain == 1.0) then 
+      if( pjin%code == kgnuc .and. Ain == 1.0) then 
          call cmkptc(knuc, -1, int(Z), pj)
-         pj.fm.p(4) = pjin.fm.p(4)/pjin.subcode
-         A = pjin.subcode
-         Z = pjin.charge
+         pj%fm%p(4) = pjin%fm%p(4)/pjin%subcode
+         A = pjin%subcode
+         Z = pjin%charge
       endif
 
 
@@ -50,7 +50,7 @@ c           using cPDGsigmaTotpA(A) at @200 GeV
       if( A /= 1.0d0 ) then 
          if(first) then
             call cmkptc(knuc, -1, 1, proton)
-            proton.fm.p(4) =  200. + masp
+            proton%fm%p(4) =  200. + masp
             first = .false.
          endif
          if( A /= Asave ) then
@@ -68,7 +68,7 @@ c           using cPDGsigmaTotpA(A) at @200 GeV
 #include "Zptcl.h"
 #include "Zcode.h"
 #include "Zevhnp.h"
-      record /ptcl/pj   !input projectile particle
+      type(ptcl)::pj   !input projectile particle
       real(8),intent(in):: A  ! effective target mass number
       real(8),intent(in):: Z  ! effective target charge
       real(8),intent(out)::xs  ! in mb. total xsection. 
@@ -76,25 +76,25 @@ c           using cPDGsigmaTotpA(A) at @200 GeV
       real*8 p
 
       real(8)::shp, shn
-      if( pj.fm.p(4) .le. pj.mass) then
-         if(pj.code .eq. knuc .and. pj.subcode .eq. antip) then
+      if( pj%fm%p(4) .le. pj%mass) then
+         if(pj%code .eq. knuc .and. pj%subcode .eq. antip) then
             xs = largexs
-         elseif(pj.code .eq. kelec .and. pj.charge .eq. 1) then
+         elseif(pj%code .eq. kelec .and. pj%charge .eq. 1) then
             xs = largexs
          else
             xs  = smallxs
          endif
       else   
-         p = sqrt(pj.fm.p(4)**2 - pj.mass**2)
-c         p = max(p, 0.1d0) 
-c         if( p .ge. 20.) then          
-c            call cerrorMsg('Momentum is >20 GeV/c for ctotx',0)
-c         endif
+         p = sqrt(pj%fm%p(4)**2 - pj%mass**2)
+!         p = max(p, 0.1d0) 
+!         if( p .ge. 20.) then          
+!            call cerrorMsg('Momentum is >20 GeV/c for ctotx',0)
+!         endif
 
-         if(pj.code .eq. knuc) then
-            if(pj.charge .eq. 1) then
-c            proton
-c               shp = ctotpp1(p)
+         if(pj%code .eq. knuc) then
+            if(pj%charge .eq. 1) then
+!            proton
+!               shp = ctotpp1(p)
                if( A == 1.0 ) then
                   if( Z == 1.0) then  ! pp
                      call cppTotXs(p, xs)
@@ -109,7 +109,7 @@ c               shp = ctotpp1(p)
                   call cppTotXs(p, shp)
                   if( nIsDiff ) then
                      call cnpTotXs(p, shn)
-c               use average of pp,pn
+!               use average of pp,pn
                      shp = (shp + shn)/2.0
                   endif
                   call cxp2xAXsec(A, shp, xs)
@@ -118,17 +118,17 @@ c               use average of pp,pn
                   write(0,*) 'strange for ctotx/ctotx2'
                   stop
                endif
-            elseif(pj.charge .eq. -1) then
-c                pbar  no n target
+            elseif(pj%charge .eq. -1) then
+!                pbar  no n target
                call cpbarpTotXs(p, shp)
                if( A .gt. 1.) then
                   call cxp2xAXsec(A, shp, xs)
                else
                   xs = shp
                endif
-            elseif(pj.subcode .eq. antip) then
-c              anti-neutron; assume the same one as pbar
-c               shp = ctotpbarp1(p)
+            elseif(pj%subcode .eq. antip) then
+!              anti-neutron; assume the same one as pbar
+!               shp = ctotpbarp1(p)
                call cnbarpTotXs(p, shp)
                if( A .gt. 1.) then
                   call cxp2xAXsec(A, shp, xs)
@@ -136,8 +136,8 @@ c               shp = ctotpbarp1(p)
                   xs = shp
                endif
             else
-c               neutron
-c               shp = ctotnp1(p)
+!               neutron
+!               shp = ctotnp1(p)
                call cnpTotXs(p, shp)
                if(A .gt. 1.) then
                   call cxp2xAXsec(A, shp, xs)
@@ -145,14 +145,14 @@ c               shp = ctotnp1(p)
                   xs = shp
                endif
             endif
-         elseif(pj.code .eq. kpion) then
-            if(pj.charge .eq. 1) then
+         elseif(pj%code .eq. kpion) then
+            if(pj%charge .eq. 1) then
                call cpippTotXs(p, shp)
-            elseif(pj.charge .eq. -1) then
+            elseif(pj%charge .eq. -1) then
                call cpimpTotXs(p, shp) 
             else
-c              at low energy, pi0 would not interact. any would be o.k
-c               shp = ctotpiMp1(p)
+!              at low energy, pi0 would not interact. any would be o.k
+!               shp = ctotpiMp1(p)
                call cpimpTotXs(p, shp)
             endif
             if(A .ne. 1.0) then
@@ -160,8 +160,8 @@ c               shp = ctotpiMp1(p)
             else
                xs = shp
             endif
-         elseif(pj.code .eq. kkaon) then
-            if(pj.charge .eq. 1) then
+         elseif(pj%code .eq. kkaon) then
+            if(pj%charge .eq. 1) then
                if( A == 1.0 ) then
                   if( Z == 1.0 ) then
                      call ckppTotXs(p, xs)
@@ -184,7 +184,7 @@ c               shp = ctotpiMp1(p)
                   write(0,*) ' strange to ctotx/ctotx2  '
                   stop
                endif
-            elseif(pj.charge .eq. -1) then  ! K-
+            elseif(pj%charge .eq. -1) then  ! K-
                call ckmpTotXs(p, shp)   ! kmp = kmn at present
                if(A .gt. 1.) then
                   if( nIsDiff ) then
@@ -196,7 +196,7 @@ c               shp = ctotpiMp1(p)
                   xs = shp
                endif
             else
-c             k0; don't worry so much 
+!             k0; don't worry so much 
                call ckmpTotXs(p, shp)
                call ckmnTotXs(p, shn)
                shp = (shp+ shn)/2.
@@ -206,21 +206,21 @@ c             k0; don't worry so much
                   xs = shp
                endif
             endif
-         elseif(pj.code .eq. kgzai .or. pj.code .eq. ksigma .or.
-     *           pj.code .eq. kbomega .or. pj.code .eq. klambda .or.
-     *           pj.code .eq. klambdac) then
-c          don't worry, not used almost at all; use proton
-c            shp = ctotpp1(p)
+         elseif(pj%code .eq. kgzai .or. pj%code .eq. ksigma .or.
+     *           pj%code .eq. kbomega .or. pj%code .eq. klambda .or.
+     *           pj%code .eq. klambdac) then
+!          don't worry, not used almost at all; use proton
+!            shp = ctotpp1(p)
             call cppTotXs(p, shp)
             call cxp2xAXsec(A, shp, xs)               
-         elseif( pj.code == kgnuc ) then
+         elseif( pj%code == kgnuc ) then
             write(0,*) 'Sorry: ctotx is not usable for heavy ions'
             write(0,*) ' only inelastic xs is used for heavy ions'
             write(0,*) ' so that you may use cinela or cAAXsec2'
             stop
          else
-c          use pion
-c            shp =ctotpiPp1(p)
+!          use pion
+!            shp =ctotpiPp1(p)
             call cpippTotXs(p, shp)
             call cxp2xAXsec(A, shp, xs)               
          endif
