@@ -333,6 +333,7 @@
         PrimaryIdTbl(54)%subcode = antip
         PrimaryIdTbl(54)%charge = -1
 
+        
         PrimaryIdTbl(55)%symb = 'nbar'
         PrimaryIdTbl(55)%code = knuc
         PrimaryIdTbl(55)%subcode = antip
@@ -353,6 +354,51 @@
         PrimaryIdTbl(58)%subcode = 0
         PrimaryIdTbl(58)%charge = 1
 
+        PrimaryIdTbl(59)%symb = 'tau+'
+        PrimaryIdTbl(59)%code =  ktau
+        PrimaryIdTbl(59)%subcode = antip
+        PrimaryIdTbl(59)%charge = 1
+
+        PrimaryIdTbl(60)%symb = 'tau-'
+        PrimaryIdTbl(60)%code =  ktau
+        PrimaryIdTbl(60)%subcode =  regptcl
+        PrimaryIdTbl(60)%charge = -1
+
+        PrimaryIdTbl(61)%symb = 'neu_tau'
+        PrimaryIdTbl(61)%code =  kneutau
+        PrimaryIdTbl(61)%subcode =  regptcl
+        PrimaryIdTbl(61)%charge = 0
+
+        PrimaryIdTbl(62)%symb = 'neu_e~'
+        PrimaryIdTbl(62)%code = kneue
+        PrimaryIdTbl(62)%subcode = antip
+        PrimaryIdTbl(62)%charge = 0
+
+        PrimaryIdTbl(63)%symb = 'neu_mu~'
+        PrimaryIdTbl(63)%code = kneumu
+        PrimaryIdTbl(63)%subcode = antip
+        PrimaryIdTbl(63)%charge = 0
+
+        PrimaryIdTbl(64)%symb = 'neu_tau~'
+        PrimaryIdTbl(64)%code =  kneutau
+        PrimaryIdTbl(64)%subcode =  antip
+        PrimaryIdTbl(64)%charge = 0
+
+        PrimaryIdTbl(65)%symb = 'pdg'
+        PrimaryIdTbl(65)%code = 0       ! later fixed
+        PrimaryIdTbl(65)%subcode = 0    ! //
+        PrimaryIdTbl(65)%charge = 0     !
+
+        PrimaryIdTbl(66)%symb = 'p~'
+        PrimaryIdTbl(66)%code = knuc
+        PrimaryIdTbl(66)%subcode = antip
+        PrimaryIdTbl(66)%charge = -1
+
+        PrimaryIdTbl(67)%symb = 'n~'
+        PrimaryIdTbl(67)%code = knuc
+        PrimaryIdTbl(67)%subcode = antip
+        PrimaryIdTbl(67)%charge = 0
+        
         
        end
 !***************************************************
