@@ -16,13 +16,12 @@
       character*70 msg
 !
       integer i, icon
-      character*10 temp1
+      character*16 temp1
 !
       icon = 0
       prm%NoOfSamplings = EventsInTheRun ! counter, including discarded ones
                                         ! how many primaries generated
       EventNo = PrevEventNo             ! the same
-
       do i = 1, prm%no_of_comps
          prm%NoOfSampComp(i, 1) =0  ! all
          prm%NoOfSampComp(i, 2) =0  ! only for accepted ones
@@ -72,7 +71,7 @@
       integer icon
 !
 !
-      character*12 symb
+      character(16):: symb  !  12->16 (2019/Aug/29)
       integer k,  pap, massn, chgn
       character*70 msg
       integer:: kf
@@ -91,7 +90,7 @@
       k = 1
       if(symb(1:3) .eq.  'iso')  then
 !                  read A, Z
-         read(symb(4:12), *) massn, chgn
+         read(symb(4:16), *) massn, chgn   !  12->16 2019/Aug/29
          if(massn .le. chgn) then
             write(msg,*) ' primary =',symb,
      *     ' invalid(becaus A=',massn,'<= Z=',chgn
@@ -100,7 +99,8 @@
          symb = 'iso'          
       elseif(symb(1:3) .eq.  'pdg')  then
 !                  read PDG code   ! no heavy primary
-         read(symb(4:12), *) kf
+         read(symb(4:16), *) kf !  12->16 2019/Aug/29  now heavy
+                                ! 1ry can be managed by pdg   
          call ckf2cos(kf, each%code, each%subcode, each%charge)
          symb = 'pdg'           ! erase kf code
          return !!!!!!!
@@ -152,7 +152,7 @@
       integer  icon
 !     
 !
-      character*12 symb
+      character(16):: symb  !  12-> 16  2019/Aug/29
       integer k
       character*70 msg
 
