@@ -1,19 +1,19 @@
-c     include '../Sysdep/copenf.f'
-c     include '../Sysdep/cskipComment.f'
-cc            test crdPrimData etc
-cc
-c     include '../Particle/Zptcl.h'
-c     include 'Zprimary.h'
-c     record /primaries/ Prm
-c     call copenf(TempDev, 
-c    * '../Data/Primary/sample.d')
-c     call cskipComment(TempDev, icon)
-c     call crdPrimData(Prm)
-c     write(*, *) ' no. of comps=', Prm.no_of_comps
-c     end
-c       *************************************************
-c       *   crdPrimData:  read primary information
-c
+!     include '../Sysdep/copenf.f'
+!     include '../Sysdep/cskipComment.f'
+!c            test crdPrimData etc
+!c
+!     include '../Particle/Zptcl.h'
+!     include 'Zprimary.h'
+!     type(primaries):: Prm
+!     call copenf(TempDev, 
+!    * '../Data/Primary/sample.d')
+!     call cskipComment(TempDev, icon)
+!     call crdPrimData(Prm)
+!     write(*, *) ' no. of comps=', Prm.no_of_comps
+!     end
+!       *************************************************
+!       *   crdPrimData:  read primary information
+!
         subroutine crdPrimData(prm)
         implicit none
 #include  "Zmanagerp.h"
@@ -22,15 +22,15 @@ c
 #include  "Zprimaryc.h"
 #include  "Zprimaryv.h"
 
-        record /primaries/ prm
-        record /component/ onecomp
-c
+        type(primaries):: prm
+        type(component):: onecomp
+!
         integer icon, n
-c
+!
         n = 0
         icon = 0
         do while(icon .eq. 0)
-c            call crdCompPrim(prm.each(n+1), 
+!            call crdCompPrim(prm.each(n+1), 
             call crdCompPrim(onecomp,
      *      n+1, icon)        ! each component of primaries.
             if(icon .eq. 0) then
@@ -38,10 +38,10 @@ c            call crdCompPrim(prm.each(n+1),
                if(n .gt. maxNoOfComps) then
                  write(0,*) ' # of 1ry comp. > maxNoOfComps=',
      *            maxNoOfComps
-                 write(0,*) ' change the value in Zmaxdef.h '
+                 write(0,*) ' change the value in Zmaxdef%h '
                  stop
               endif
-              prm.each(n)= onecomp
+              prm%each(n)= onecomp
             endif
         enddo
 
@@ -51,15 +51,15 @@ c            call crdCompPrim(prm.each(n+1),
            write(*,*) ' no primary is given'
            stop 9999
         endif
-        prm.no_of_comps = n
+        prm%no_of_comps = n
       end
-c     ***********************************************
+!     ***********************************************
       subroutine crdCompPrim(each, n, icon)
-c     ***********************************************
-c          each: /component/. Output.  one composition of primary data is read
-c            n: integer. Input. n+1-th block in the table is next data
-c         icon: integer. output. 0--> more data
-c                                1--> eof reached.
+!     ***********************************************
+!          each: /component/. Output.  one composition of primary data is read
+!            n: integer. Input. n+1-th block in the table is next data
+!         icon: integer. output. 0--> more data
+!                                1--> eof reached.
         implicit none
 
 #include  "Zmanagerp.h"
@@ -68,22 +68,22 @@ c                                1--> eof reached.
 #include  "Zprimaryc.h"
         integer n   !n+1-th primary data in the table is being read
         integer  icon
-        record /component/ each
+        type(component):: each
         integer ios, np    ! np is the data points counter
-c                 read 1ry type, energy unit, energy type, etc
-         each.cut = 0.
-         each.cut2 = 0.
-         read(TempDev, *, iostat=ios) each.symb, each.eunit,
-     *   each.etype, each.diff_or_inte,  each.flatterer, each.cut,
-     *   each.cut2
-c
+!                 read 1ry type, energy unit, energy type, etc
+         each%cut = 0.
+         each%cut2 = 0.
+         read(TempDev, *, iostat=ios) each%symb, each%eunit,
+     *   each%etype, each%diff_or_inte,  each%flatterer, each%cut,
+     *   each%cut2
+!
          if(ios .eq. 0) then
-c                 ! not yet eof or no error
+!                 ! not yet eof or no error
               np = 0       ! segment counter
               do while(.true.)  ! read until end of 1 block
                   read(TempDev, *, iostat =ios)
-     *            each.energy(np+1),
-     *            each.flux(np+1)
+     *            each%energy(np+1),
+     *            each%flux(np+1)
                   if(ios .ne. 0) then
                       write(*, *) ' error in the primary data'
                       write(*, *) ' data position: Primary block=', 
@@ -91,8 +91,8 @@ c                 ! not yet eof or no error
                       close(TempDev)
                       stop 9999
                   endif
-c                     see if end of the composition
-                  if(each.energy(np+1) .le. 0.) goto 100
+!                     see if end of the composition
+                  if(each%energy(np+1) .le. 0.) goto 100
                   np = np + 1
                   if(np .gt. maxSegments+1) then
                      write(*, *) 'too many segments in ',n+1,
@@ -102,9 +102,9 @@ c                     see if end of the composition
                   endif   
              enddo
  100         continue
-             each.no_of_seg =max(0, np -1) ! segments
-c                 note that each.no_of_seg is data points -1
-c                (2 points makes a segment !)
+             each%no_of_seg =max(0, np -1) ! segments
+!                 note that each.no_of_seg is data points -1
+!                (2 points makes a segment !)
              icon = 0
         else
              icon = 1    ! eof
