@@ -8,7 +8,8 @@ if [ $# -ne 1 ]; then
 EOF
     exit
 fi
-vn=`awk --version | awk '{gsub(/[\.,]/,"",$3);print $3;exit}'`
+#alias awk='/usr/local/bin/gawk'
+vn=`gawk --version | gawk '{gsub(/[\.,]/,"",$3);print $3;exit}'`
 if [ $vn -lt 316 ] || [ $vn -gt 700 ]; then
   cat <<EOF
   awk verson is too old.  Please use gnu awk of version >= 3.1.6
@@ -27,7 +28,7 @@ fi
 
 cp $file ${file}-bkup
 
-awk -f  $COSMOSTOP/Scrpt/dot2perc.awk $file > temp1temp1
+gawk -f  $COSMOSTOP/Scrpt/dot2perc.awk $file > temp1temp1
 #   sed -f  $COSMOSTOP/Scrpt/dot2perc.sed temp1temp1 > temp2temp2
 
 
