@@ -1,3 +1,9 @@
+!!!!!!!
+      module moddebug
+      implicit none
+      logical,save::  dodebug=.false.
+      end   module moddebug
+
       subroutine ciniTracking( incident )
 !          this is called after primary is fixed.
       implicit none
@@ -65,7 +71,8 @@
          call csetObsZ(cxyz2prim)
 !          inicident.where can be fixed here. not  in cmkIncidnt
          call cxyz2prim(ObsSites(NoOfSites)%pos%xyz, 
-     *                  incident%pos%xyz, xyz)         
+     *        incident%pos%xyz, xyz)
+         
          do i = 1, NoOfSites
             if(xyz%r(3) .gt. ObsSites(i)%zpl ) then
                incident%where = i
@@ -73,8 +80,8 @@
             endif
          enddo
          incident%where = NoOfSites + 1
-         IncidentCopy%where = incident%where
  222     continue
+         IncidentCopy%where = incident%where
       elseif(ObsPlane .eq.  notUsed ) then
 !           Nothing to do. observation is at height =
 !           BorderHeighL. (for neutrino)
@@ -90,8 +97,10 @@
      *    abs( AngleAtObsCopy%r(3) ) .lt. 0.5 )
       UseTbl = UseTbl .and.  .not. Upgoing
       if(UseTbl .and. zAngleSave .ne. AngleAtObsCopy%r(3) ) then
-         Hbase = HeightList(NoOfSites) - 0.3d0  ! make little bit smaller
-         Htop =100.d3   ! old value was 30d3
+         Htop =  atmos%z(atmos%nodes) !  2016/Jun/20
+         Hbase = atmos%z(1)     !
+!         Hbase = HeightList(NoOfSites) - 0.3d0  ! make little bit smaller
+!         Htop =100.d3   ! old value was 30d3
          r1 = Htop + Eradius
          r2 = Hbase + Eradius
          lengx = clenbetween2h(r2, r1, -AngleAtObsCopy%r(3))
@@ -129,8 +138,18 @@
 !      compute Xprimary, Yprimary, Zprimary in 'xyz' system.
 
       real*8  temp
-!      
-      Zprimary%r(:) = - DcAtObsXyz%r(:)
+
+      type(coord):: angle
+      type(track):: incident
+      
+      call cqIncident(incident, angle)
+!!     2020/Jan./11
+      if(incident%vec%coszenith < 0.) then
+         Zprimary%r(:) =  DcAtObsXyz%r(:)
+      else
+         Zprimary%r(:) = - DcAtObsXyz%r(:)
+      endif
+!!      
       call cvecProd(Zprimary, DetZaxis, Xprimary)
 !         see if Zprimary // DetZaxis; if so reset Xprimary
       temp= sum( Xprimary%r(:)**2 )
@@ -170,7 +189,7 @@
       type(coord)::temp
 !        compute z from the base detector.
       do i = 1, NoOfSites
-         call converter(ObsSites(NoOfSites)%pos%xyz, 
+         call converter(ObsSites(NoOfSites)%pos%xyz,
      *     ObsSites(i)%pos%xyz,
      *     temp)
          ObsSites(i)%zpl = temp%r(3)
@@ -178,8 +197,7 @@
 !            this is for A.S
       do i = 1, NoOfASSites
          call converter(ASObsSites(NoOfASSites)%pos%xyz, 
-     *     ASObsSites(i)%pos%xyz,
-     *     temp)
+     *     ASObsSites(i)%pos%xyz,  temp)
          ASObsSites(i)%zpl = temp%r(3)
       enddo
       end
