@@ -26,7 +26,11 @@
       do while (.true.)
 !           get one particle from stack
          call cpop(TrackBefMove, moreptcl)
-         if(moreptcl .eq. 0) goto 100   !  exit
+!     track is not yet moved but make a copy for safety (without this
+!     problem after path truncation could happen.
+         MovedTrack = TrackBefMove
+
+         if(moreptcl .eq. 0) goto 100 !  exit
          call rndsw(jold, 1)            !  specify 1st generator.
          call cifDead(TrackBefMove, icon)  ! generator may be switched to 2
             
@@ -75,7 +79,10 @@
 ! -------------------------------------tracking a ptcl
       subroutine cTracking
       use modXsecMedia, only: TargetNucleonNo, TargetProtonNo,
-     * TargetXs
+     *     TargetXs
+!!!!!!!!!!!!      
+      use moddebug
+!!!!!!!!!!!!      
       implicit none
 
 #include  "Ztrack.h"
@@ -140,7 +147,12 @@
 !           see if MovedTrack crosses an observation site.
 !         (or reaches BorderHeightL)  If so, reset MovedTrack. 
       call cifXObsSite(nextwhere)
-
+!!!!!!!!!!!
+      if(dodebug) then
+         write(0,*) ' ' 
+         write(0,*) ' after cifXOb ,nextwher=',nextwhere
+      endif
+!!!!!!!!!!!!!!      
 
       if(TrackBefMove%p%charge .ne. 0 .and. Eabsorb(1) .ne. 0) then
 !               4th arg. not used now
@@ -163,7 +175,16 @@
       call cobservation(8)
 #endif
 
-!     
+!
+!!!!!!!!!!!!!
+      if(dodebug) then
+         write(0,*) 'in tracking: MoveStat=',MoveStat
+         write(0,*) '  Truncated =', Truncated
+         write(0,*) ' TobBeObserved=',ToBeObserved
+         write(0,*) ' MOved H=',MovedTrack%pos%height
+      endif
+!!!!!!!!!!
+         
       if(MoveStat .eq. Truncated) then
 !        &&&&&&&&&&&&&& some may lose energy by dE/dx etc. 
 !                       This should be recorded
@@ -174,7 +195,14 @@
             call chookEInt(never)
          endif
 !        &&&&&&&&&&&&
-!              stack current ptcl
+!     stack current ptcl
+!!!!!!!111
+         if( dodebug ) then
+            write(0,*) ' trucated push'
+            write(0,*) 'push Moved where =', MovedTrack%where,
+     *           MovedTrack%pos%height
+         endif
+!!!!!!!!!!!!!!!!!!         
          call cpush(MovedTrack)
       elseif(MoveStat .eq. ToInteract ) then
          if(Zfirst%pos%depth .eq. 0.) then
@@ -231,7 +259,12 @@
      *        .ge. KEminObs(ptclidx) ) then    ! .gt. for <= uv6.00
 !             call only for high energy particles
 !                  (at AS generation, some ptcl may have < KEminObs
-!                  or some may loose energy by dE/dx etc.
+!     or some may loose energy by dE/dx etc.
+!!!!!!!!!!!!
+            if(dodebug) then
+               write(0,*) ' Entering cobservation(2)'
+            endif
+!!!!!!!!!!!!!            
             call cobservation(2)
 
             if(Job .eq. 'newskel' .and.
@@ -260,10 +293,17 @@
 !               update observation place
 !         if(abs(ObsPlane) .eq. perpendicular) then
          MovedTrack%where = nextwhere
-!                  if more obs-site, stack current ptcl.
+!     if more obs-site, stack current ptcl.
+!!!!!!!!!
+         if( dodebug ) then
+            write(0,*) 'iMoved where updated to ', nextwhere
+            write(0,*) ' upgoing=', upgoing
+            write(0,*) ' EndLevel=',  EndLevel
+         endif
+!!!!!!!!!!         
          if(.not. Upgoing) then ! incident is downgoing
             if(MovedTrack%where .gt. EndLevel) then
-                                ! no need to stack; discard ptcl.
+! no need to stack; discard ptcl.
             else
                MovedTrack%where =max( MovedTrack%where*1, 1)
                call cpush(MovedTrack)
@@ -282,11 +322,18 @@
 !            call cpush(MovedTrack)
 !         endif
       elseif(MoveStat .eq. BorderL) then
+!!!!!!!!!!!
+         if(dodebug) then
+            write(0,*) ' MoveStat is BorderL'
+            write(0,*) ' Moved h=', MovedTrack%pos%height
+            write(0,*) ' goto cobservatio (3) then push'
+         endif
+!!!!!!!!!!         
          call cobservation(3)
-         call cpush(MovedTrack)
+         call cpush(MovedTrack)  !  2020/Jan/13 infinite tracking
       elseif(MoveStat .eq. BorderH) then
          call cobservation(1)
-         call cpush(MovedTrack)
+         call cpush(MovedTrack)  ! 2020/Jan/13 infinite tracking
       else
          write(msg, *) ' movestat=',MoveStat,' invalid'
          call cerrorMsg(msg, 0)
@@ -484,6 +531,9 @@
       end
 !     **************************** cfixProc **********
       subroutine cfixProc
+!!!!!!!!!!
+      use moddebug
+!!!!!!!!      
       implicit none
 
 #include  "Zglobalc.h"
@@ -567,6 +617,9 @@
 !        given in InfIntArray is too long, or the path traverses
 !        an observation depth.
       subroutine ctruncPath
+!!!!!!!!!!1
+      use moddebug
+!!!!!!!!!      
       implicit none
 #include  "Zcode.h"
 #include  "Ztrack.h"
