@@ -1,58 +1,58 @@
-c      make next <=0 for ascii write for individual ptcl info.
-c      Normmally binary output is gathered and converted into
-c      ascii in the last stage so this is kept as it is.
-c      33 is used as fortran file no.
+!      make next <=0 for ascii write for individual ptcl info.
+!      Normmally binary output is gathered and converted into
+!      ascii in the last stage so this is kept as it is.
+!      33 is used as fortran file no.
 #define FNODATDEF 33
-c          standard
+!          standard
 #define BUFSIZE  100000
-c          prog. size upto 512MB at kekb.  no disk I/O
-c  #define BUFSIZE 2000000
-c       define next if reduce the output size(.dat and rec of .nrfai)
-c       on fly even at non-mpi env.
+!          prog. size upto 512MB at kekb.  no disk I/O
+!  #define BUFSIZE 2000000
+!       define next if reduce the output size(.dat and rec of .nrfai)
+!       on fly even at non-mpi env.
 
-c
+!
 #if defined (KEKB) || defined (KEKA) 
 #define DOMPI
 #endif
-c   output:
-c    Layer specification where output data is taken is
-c    determined as follows
-c    A) ASDepthList.   This is for .hyb data.  
-c         ASDepthList(i), i=1, NoOfASSites
-c    B) DepthList.  This is for web "all" and web "dEdx"
-c         DepthList(i), i=1, NoOfSites
-c        B') With additional param.   
-c           indivdep(i)  for individual ptcl output.
-c           (i=1, ansites) (ansites<=NoOfSies). j=indivdep(i)
-c           gives the layer number.
-c           histdep(i)   for histogram  output.
-c           (i=1, hnsites) (hnsites<=NoOfSites). j=histdep(i)
-c           gives the layer number.
-c 
-c    1)   web data
-c            rec: count no. of particles of each type
-c                 for which we recorded individual ptcl
-c                 type info.   (indivdep)
-c         
-c            all: for all layers. count the number of
-c                     each ptcl type which passes the
-c                     given layer.  
-c           dEdx: for all layers. count dE/dx of charged
-c                 ptcls which pass the given layer
-c                  
-c    2)  hyb data
-c               all layers (NoOfASSites)
-c    3) .dat   for only specified 1 or few layers. individual
-c              info.  corresponding to web "rec" data.
-c    4) .hist  sub set of .dat layers.
-c          lateral distribution corresponding to each fai
-c             bin of the web sector. Layers are specifed by
-c             histdep(i).
-c            
-c          time distribution. At each web sector. Layers are the
-c              same as the lateral hist.
-c               
-c       
+!   output:
+!    Layer specification where output data is taken is
+!    determined as follows
+!    A) ASDepthList.   This is for .hyb data.  
+!         ASDepthList(i), i=1, NoOfASSites
+!    B) DepthList.  This is for web "all" and web "dEdx"
+!         DepthList(i), i=1, NoOfSites
+!        B') With additional param.   
+!           indivdep(i)  for individual ptcl output.
+!           (i=1, ansites) (ansites<=NoOfSies). j=indivdep(i)
+!           gives the layer number.
+!           histdep(i)   for histogram  output.
+!           (i=1, hnsites) (hnsites<=NoOfSites). j=histdep(i)
+!           gives the layer number.
+! 
+!    1)   web data
+!            rec: count no. of particles of each type
+!                 for which we recorded individual ptcl
+!                 type info.   (indivdep)
+!         
+!            all: for all layers. count the number of
+!                     each ptcl type which passes the
+!                     given layer.  
+!           dEdx: for all layers. count dE/dx of charged
+!                 ptcls which pass the given layer
+!                  
+!    2)  hyb data
+!               all layers (NoOfASSites)
+!    3) .dat   for only specified 1 or few layers. individual
+!              info.  corresponding to web "rec" data.
+!    4) .hist  sub set of .dat layers.
+!          lateral distribution corresponding to each fai
+!             bin of the web sector. Layers are specifed by
+!             histdep(i).
+!            
+!          time distribution. At each web sector. Layers are the
+!              same as the lateral hist.
+!               
+!       
 
       subroutine xBgRun
       implicit none
@@ -83,7 +83,7 @@ c
       real*8  etime1, etime2 
       character*10 numbr
       integer lengnr, rank, rankc
-c         to gatter sum of the  all rank data 
+!         to gatter sum of the  all rank data 
       real nrfaiRecA(nrbin, nfai, 4, nsites)
       real nrfaiAllA(nrbin, nfai, 4, nsites)
       real dErfaiA(nrbin, nfai,  nsites)
@@ -97,8 +97,8 @@ c         to gatter sum of the  all rank data
 #define  REALLIMITmu 7500
 #define  REALLIMITh  7500
 #endif
-      record /track/ incident
-      record /coord/ AngleAtObs
+      type(track):: incident
+      type(coord):: AngleAtObs
 
       logical  HEobs            ! if T, currently observing 
       common /ZHEobs/ HEobs     !  particle is the one  obsrved at skeelton making time
@@ -106,14 +106,14 @@ c         to gatter sum of the  all rank data
 
 
       integer id  ! input.  1 ==> aTrack is going out from                      
-c                                 outer boundery.
-c                           2 ==> reached at an observation level
-c                           3 ==> reached at inner boundery.
-      record /track/ aTrack
+!                                 outer boundery.
+!                           2 ==> reached at an observation level
+!                           3 ==> reached at inner boundery.
+      type(track):: aTrack
 
-      record /track/ inci
-      record /coord/ angle
-      record /coord/ tetafai
+      type(track):: inci
+      type(coord):: angle
+      type(coord):: tetafai
       
       character*128 input
       character*64 dirstr
@@ -162,14 +162,14 @@ c                           3 ==> reached at inner boundery.
       real*8 getFai
       logical dosort
       real prob, tmin, dt
-c     ***********************
+!     ***********************
 #include "interface2.h"
-c     *********************
-c     example
-c       histdep:  2 5 6 7 10 /
-c       depth   1000 2000 3000 4000 5000 6000 7000 8000 9000 10000
-c       ansites = 5
-c       w2hl: 0 1 0 0 2 3 4 0 0 5  0 0 ...
+!     *********************
+!     example
+!       histdep:  2 5 6 7 10 /
+!       depth   1000 2000 3000 4000 5000 6000 7000 8000 9000 10000
+!       ansites = 5
+!       w2hl: 0 1 0 0 2 3 4 0 0 5  0 0 ...
       
 
 
@@ -219,10 +219,10 @@ c       w2hl: 0 1 0 0 2 3 4 0 0 5  0 0 ...
          w2il( indivdep(i) ) = i
       enddo
 
-c        now hnsites is the  actual number of sites where statistics
-c        by histogram is needed.
-c        mapping; depth index to array index; where2loc
-c     
+!        now hnsites is the  actual number of sites where statistics
+!        by histogram is needed.
+!        mapping; depth index to array index; where2loc
+!     
 
  
       call kwhistso( binw )  ! specify binary or ascii write of histogaram
@@ -239,14 +239,14 @@ c
       enddo
 
       return      
-c    ******************
+!    ******************
       entry xihist
-c
-c
+!
+!
 
-c     histogram: instanciate
-c         rspec (lateral):  
-c       
+!     histogram: instanciate
+!         rspec (lateral):  
+!       
 
       if(tkarspec) then
          do i = 1, hnsites
@@ -274,7 +274,7 @@ c
 
           do i = 1, hnsites
              do j = 1, 4
-c                at  center
+!                at  center
                 call kwhisti( tspec0(j, i),
      *               -5., 0.1, 200, b'00000')
                 call kwhistai( tspec0(j, i),
@@ -323,9 +323,9 @@ c                at  center
          enddo
       endif
       return
-c    ******************
+!    ******************
       entry xclearNrfai
-c
+!
       
       do i = 1, NoOfSites
          do j= 1, 4
@@ -351,11 +351,11 @@ c
 
 
       return
-c     *********************************** hook for Beginning of  1 event
-c     *  All system-level initialization for 1 event generation has been
-c     *  eneded at this moment.
-c     *  After this is executed, event generation starts.
-c     *
+!     *********************************** hook for Beginning of  1 event
+!     *  All system-level initialization for 1 event generation has been
+!     *  eneded at this moment.
+!     *  After this is executed, event generation starts.
+!     *
       entry xBgEvent
 #if defined (DOMPI)
       etime1 = MPI_WTIME()
@@ -370,19 +370,19 @@ c     *
 
       cosz = -angle.r(3)
       Fai0 = getFai( -angle.r(1), -angle.r(2)) ! in deg.
-c          to rotate coordinate and direction cos in the
-c          Obsplane =1 system (x is directed to magnetic east
-c          y is to the magnetic  north) to the one in the 
-c          system with the x-axis directed to the incident
-c          direction. All outuput from this program is
-c          measured in this system.  (web data too).
-c          Z* = Z exp(-(Fai0)) ;  Z in the detector system
-c          Z* in the web system.
-c
+!          to rotate coordinate and direction cos in the
+!          Obsplane =1 system (x is directed to magnetic east
+!          y is to the magnetic  north) to the one in the 
+!          system with the x-axis directed to the incident
+!          direction. All outuput from this program is
+!          measured in this system.  (web data too).
+!          Z* = Z exp(-(Fai0)) ;  Z in the detector system
+!          Z* in the web system.
+!
       CosRot = cos(Fai0*Torad)
       SinRot = sin(Fai0*Torad)
-c       
-c
+!       
+!
       E0 = inci.p.fm.p(4)
       if(inci.p.code .eq. 9) then
          NN= inci.p.subcode
@@ -391,16 +391,16 @@ c
       else
          NN=1
       endif
-c         next is only available for parallel job.  For normal job,
-c         fisrt col.depth is not yet fixed.
+!         next is only available for parallel job.  For normal job,
+!         fisrt col.depth is not yet fixed.
       firstz= Zfirst.pos.depth*0.1
       write(0,'(a,1pE11.3,a,E11.3,a,E11.3,a)')
      *     ' E0=',E0, ' cosz=',cosz, ' firstz=',
      *    firstz, ' g/cm2' 
-c          here we use enhanced limit
+!          here we use enhanced limit
       call howmuch(limite, E0, NN, cosz)
 
-c      
+!      
       do i = 1, NoOfSites
          SumEloss(i) = 0.
          Ng(i) = 0.
@@ -412,21 +412,21 @@ c
       obstimes = 0.
 
       return
-c     ***************
+!     ***************
       entry xObs(aTrack, id)
-c
-c     For id =2, you need not output the z value, because it is always
-c     0 (within the computational accuracy).
-c
-c    ------------------------------------------
+!
+!     For id =2, you need not output the z value, because it is always
+!     0 (within the computational accuracy).
+!
+!    ------------------------------------------
       if(Fai0 .ne. 0. ) then
-c         rotate to the web system
+!         rotate to the web system
          call det2web( aTrack.vec.w.r(1), aTrack.vec.w.r(2),
      *                 aTrack.vec.w.r(1), aTrack.vec.w.r(2))
          call det2web( aTrack.pos.xyz.x, aTrack.pos.xyz.y,
      *       aTrack.pos.xyz.x, aTrack.pos.xyz.y)
       endif
-c    ------------------------------------------
+!    ------------------------------------------
       obstimes = obstimes + 1.d0
       if(mod(obstimes, 500000.d0) .eq. 0. ) then 
          dosort=.false.
@@ -450,7 +450,7 @@ c    ------------------------------------------
             write(0,*)' stack tops=', Stack(i).p.fm.p(4)
          enddo
       endif
-c     ***************
+!     ***************
       code = aTrack.p.code
       ldep =  aTrack.where
 
@@ -482,55 +482,55 @@ c     ***************
 
          Ek = aTrack.p.fm.p(4) -aTrack.p.mass
 
-c       ------------- compute energy loss rate
+!       ------------- compute energy loss rate
          if(aTrack.p.charge .ne. 0  ) then
 
-c             -----------------
-c                      /|    |
-c                     / |   1g/cm2k
-c                    /A |    |
-c            -------------------
-c                  / ptcl direction  
-c         get energy loss when aTrack goes some distance
-c         of which vertical gramage is 1g/cm2.
-c         Gramage the particle travel is 
-c         1/cos where cos is the cos of angle (i.e, A if Fig)
-c          in the detctor system.
-c         1g/cm^2 = 10-3kg/10-4 m^2 =10 kg/m^2.
-c         To travel  1 g/cm^2  along shower axis, the ptcl must
-c         run dist kg/m^2
+!             -----------------
+!                      /|    |
+!                     / |   1g/cm2k
+!                    /A |    |
+!            -------------------
+!                  / ptcl direction  
+!         get energy loss when aTrack goes some distance
+!         of which vertical gramage is 1g/cm2.
+!         Gramage the particle travel is 
+!         1/cos where cos is the cos of angle (i.e, A if Fig)
+!          in the detctor system.
+!         1g/cm^2 = 10-3kg/10-4 m^2 =10 kg/m^2.
+!         To travel  1 g/cm^2  along shower axis, the ptcl must
+!         run dist kg/m^2
             if(abs(wz) .gt. 1.d-2) then
                dist =10./wz    ! in kg/m2/(g/cm2)
             else
-c                 for safety
+!                 for safety
                dist =1000.
             endif
             if( HEobs ) then
-c                   the ptcls is the one obsrved at skeleton making time
-c                   we must compute dE/dt here
+!                   the ptcls is the one obsrved at skeleton making time
+!                   we must compute dE/dt here
                rho = cvh2den(aTrack.pos.height)
                call cdedxInAir(aTrack.p, rho, dedt) ! dedt; GeV/(kg/m2)
                if(aTrack.p.code .eq. kmuon ) then
-c                 dE/dx due to muon pair, brem, nuc.i
+!                 dE/dx due to muon pair, brem, nuc.i
                   call cmudEdx(MuNI, MuBr, MuPr, aTrack.p.fm.p(4),
      *                 dedxmu)  ! dedxmu in GeV/(g/cm2)
                   dedxmu = dedxmu /10. !  GeV/(kg/m2)
                   dedt = dedt + dedxmu
                endif
             else
-c               we can use already computed one
+!               we can use already computed one
                call cqElossRate(dedt) !  loss rate GeV/(kg/m^2)
             endif
-c                       energy in 1 g/cm2 of vertical direction
+!                       energy in 1 g/cm2 of vertical direction
             Eloss =min( dedt*dist, dble(Ek)) * enhance  !  GeV/(g/cm2)
 
             SumEloss(ldep)=SumEloss(ldep) + Eloss
          else
             Eloss=0.
          endif
-c          
-c          get web sector indexes (r and fai index )
-c
+!          
+!          get web sector indexes (r and fai index )
+!
          molu = ObsSites(ldep).mu
          rinmu =r/molu
          sr = rinmu
@@ -539,18 +539,18 @@ c
          else
             ridx =0
          endif
-c              fai is  in    -15 to 345  (for dfai=30.)
+!              fai is  in    -15 to 345  (for dfai=30.)
          fai=getFai(aTrack.pos.xyz.x, aTrack.pos.xyz.y)
          fai= mod(fai + 360.d0,   360.d0)
          if(fai .gt. (360.d0-dfai/2.0d0)) fai= fai-360.d0
          faiidx=(fai+dfai/2.0d0) /dfai + 1
-c
+!
          if(ridx .gt. 0 .and. ridx .le. nrbin ) then
-c               for all particles
+!               for all particles
             nrfaiAll(ridx, faiidx, codex, ldep) =
      *           nrfaiAll(ridx, faiidx, codex, ldep) + enhance
             if(SeeLowdE) then 
-c                 separate low energy contribution ; Eloss = 0 for neutral 
+!                 separate low energy contribution ; Eloss = 0 for neutral 
                if(Ek .gt. 500.d-6) then
                   dErfai(ridx, faiidx, ldep) =
      *                 dErfai(ridx, faiidx,  ldep) +  Eloss
@@ -559,13 +559,13 @@ c                 separate low energy contribution ; Eloss = 0 for neutral
      *                 dErfai2(ridx, faiidx,  ldep) +  Eloss
                endif
             else
-c                don't separate low E and high E ptcls
+!                don't separate low E and high E ptcls
                dErfai(ridx, faiidx, ldep) =
      *              dErfai(ridx, faiidx,  ldep) +  Eloss
             endif  
-c
-c             ==============
-c               for  individual particle
+!
+!             ==============
+!               for  individual particle
             ji = w2il(ldep)     !  indivdep index.
             if(ji .gt.  0 ) then
                prob =  recprob(ridx, codex, ji)
@@ -573,8 +573,8 @@ c               for  individual particle
                   wwgt = wgt
                   accept = .true.
                else
-c                 Example:  if prob=10^-3 and wgt=2x10^3, 
-c                  record it with weight =2 (=prob*wgt)
+!                 Example:  if prob=10^-3 and wgt=2x10^3, 
+!                  record it with weight =2 (=prob*wgt)
                   prob = prob*wgt ! wgt =1 or wgt > 1
                   if(prob .gt. 1.) then
                      wwgt = prob
@@ -637,7 +637,7 @@ c                  record it with weight =2 (=prob*wgt)
 
 
 
-c        ================ for histograming
+!        ================ for histograming
          i=w2hl(ldep)
          if(i .gt. 0 ) then
             if(tkarspec) then
@@ -656,9 +656,9 @@ c        ================ for histograming
          endif       
       endif   ! code and id judge
       return
-c     **************
+!     **************
       entry xEnEvent
-c     **************
+!     **************
 #if FNODATDEF > 0
 #if BUFSIZE < 200000 
       if(bufc .gt. 0) then
@@ -694,7 +694,7 @@ c     **************
       endif
 #endif
 
-c       fwollowings are not supported in MPI job.
+!       fwollowings are not supported in MPI job.
 #if ! defined (DOMPI)
       do i = 1, hnsites
          j = histdep(i)
@@ -718,7 +718,7 @@ c       fwollowings are not supported in MPI job.
                   call kwhistev( rspec(j, l, i), EventNo)
                   call kwhistid( rspec(j, l,  i), evid(i))
                   call kwhistp( rspec(j, l, i),  fno)
-c                        *********** deallocate ********           
+!                        *********** deallocate ********           
                   call kwhistd( rspec(j, l, i) )
                enddo  ! code loop
             enddo ! fai loop
@@ -738,7 +738,7 @@ c                        *********** deallocate ********
                call kseblk( dirstr, "|", nstr)
                call kwhistdir( tspec0(j,i),  dirstr )
                call kwhistp( tspec0(j,i),  fno )
-c                 *********** deallocate ********                  
+!                 *********** deallocate ********                  
                call kwhistd( tspec0(j,i) )
 
                do ifai= 1, nfai
@@ -752,7 +752,7 @@ c                 *********** deallocate ********
                      call kseblk(dirstr, "|", nstr)
                      call kwhistdir(tspec(j,ir, ifai,i),  dirstr)
                      call kwhistp( tspec(j,ir, ifai,i),  fno)
-c                        *********** deallocate ********           
+!                        *********** deallocate ********           
                      call kwhistd( tspec(j, ir, ifai, i) )
                   enddo
                enddo
@@ -768,7 +768,7 @@ c                        *********** deallocate ********
 #include "Zobs.h"
 #include "Zprivate.h"
 #include "Zprivate2.h"
-      record /histogram1/ h
+      type(histogram1):: h
       integer i
       write(0,*) ' h%c%init=', h%c%init
       write(0,*) ' h%c%title=', h%c%title
@@ -781,7 +781,7 @@ c                        *********** deallocate ********
       real*8 function getFai(x, y)
       implicit none
 #include "Zglobalc.h"
-c        get polar angle of the point (x,y) in deg.
+!        get polar angle of the point (x,y) in deg.
       real*8 x, y  ! input postion or direction-cos components
       getFai = atan2(y, x)*Todeg
       end
@@ -796,9 +796,9 @@ c        get polar angle of the point (x,y) in deg.
                !  where the x-axis is directed to the incident
                !  xs,ys can be x,y
       
-c      Z* = Z * exp(-Fai0) = (x + iy)(cos-i sin)
-c                          = x cos  + y sin + i ( y cos -x sin)
-c
+!      Z* = Z * exp(-Fai0) = (x + iy)(cos-i sin)
+!                          = x cos  + y sin + i ( y cos -x sin)
+!
       real*8 temp
       temp = x*CosRot + y*SinRot
       ys = y*CosRot - x*SinRot
