@@ -1,7 +1,8 @@
 #include "cmain.f"
 #include "chookHybAS.f"
-#include "ctemplCeren.f"
-#include "cmyEfield.f"
+!!! #include "ctemplCeren.f" not needed now
+
+          !  #include "cmyEfield.f"
 #if defined (KEKB) || defined (KEKA)
 #define DOMPI
 #endif
