@@ -1,6 +1,6 @@
 #include "cmain.f"
 #include "chookHybAS.f"
-#include "ctemplCeren.f"
+! #include "ctemplCeren.f"
 #if defined (KEKB) || defined (KEKA)
 #define DOMPI
 #endif
