@@ -4,7 +4,7 @@
 !
 #include "cmain.f"
 #include "chookHybAS.f"
-#include "ctemplCeren.f"
+!  #include "ctemplCeren.f"
 !
 !  *************************************** hook for Beginning of a Run
 !  * At this moment, all (system-level) initialization for this run
@@ -49,7 +49,7 @@
       call cgetfname(msg, Wskel)  ! add host name etc if neededn
       call cqUHookc(3, append)    ! append data, if Mskel already exists
 
-      write(msg, *) 'Skeleton is  judged at obs.pos=', Where
+      write(msg, *) 'Skeleton is  judged at obs%pos=', Where
       call cerrorMsg(msg, 1)
       write(msg, *) ' Ngmin=',NgMin,
      *     ' SumEGmin=',SumegMin/1000.,'TeV'
@@ -124,9 +124,9 @@
       bgevent = .true.
       Np = 0
       call cqIncident( incident, angle)
-      kepn = incident.p.fm.p(4)
-      if( incident.p.code .eq. kgnuc ) then
-         kepn = kepn/ incident.p.subcode
+      kepn = incident%p%fm%p(4)
+      if( incident%p%code .eq. kgnuc ) then
+         kepn = kepn/ incident%p%subcode
       endif
       Ethresh = kepn * WaitRatio
 
@@ -145,15 +145,15 @@
       EventNo = EventNo + 1     
       do i = 1, NoOfSites
          write(*, 1000)
-     *    sngl(ObsSites(i).pos.depth),
+     *    sngl(ObsSites(i)%pos%depth),
      *    EventNo, 
-     *    incident.p.code,
-     *    incident.p.subcode,
-     *    incident.p.charge, 
-     *    incident.p.fm.e,
-     *    -angle.r(1),
-     *    -angle.r(2),
-     *    -angle.r(3)
+     *    incident%p%code,
+     *    incident%p%subcode,
+     *    incident%p%charge, 
+     *    incident%p%fm%e,
+     *    -angle%r(1),
+     *    -angle%r(2),
+     *    -angle%r(3)
  1000       format(f10.3,i9,3i4,e15.5,3(1x,f12.8))
       enddo
 
@@ -200,36 +200,36 @@
       save
                         
                         
-      if( id .eq. 2 .and. aTrack.p.code .ne. kneumu .and.
-     *   aTrack.p.code .ne. kneue) then
+      if( id .eq. 2 .and. aTrack%p%code .ne. kneumu .and.
+     *   aTrack%p%code .ne. kneue) then
          Np = Np + 1
          if( Np .gt. NpMax) then
             call cerrorMsg(
      *      '# of particles >NpMax in observation', 0)
          endif
-         o(Np).where = aTrack.where
-         o(Np).code = aTrack.p.code
-         o(Np).subcode = aTrack.p.subcode
-         o(Np).charge = aTrack.p.charge
-         o(Np).atime = aTrack.t
-         o(Np).erg = aTrack.p.fm.p(4)
-         o(Np).mass = aTrack.p.mass
-         o(Np).x = aTrack.pos.xyz.r(1)
-         o(Np).y = aTrack.pos.xyz.r(2)
-         o(Np).wx =aTrack.vec.w.r(1)
-         o(Np).wy =aTrack.vec.w.r(2)
-         o(Np).wz =aTrack.vec.w.r(3)
-         o(Np).zenith = aTrack.vec.coszenith
-         o(Np).wgt = aTrack.wgt
-         o(Np).user =  aTrack.user
+         o(Np)%where = aTrack%where
+         o(Np)%code = aTrack%p%code
+         o(Np)%subcode = aTrack%p%subcode
+         o(Np)%charge = aTrack%p%charge
+         o(Np)%atime = aTrack%t
+         o(Np)%erg = aTrack%p%fm%p(4)
+         o(Np)%mass = aTrack%p%mass
+         o(Np)%x = aTrack%pos%xyz%r(1)
+         o(Np)%y = aTrack%pos%xyz%r(2)
+         o(Np)%wx =aTrack%vec%w%r(1)
+         o(Np)%wy =aTrack%vec%w%r(2)
+         o(Np)%wz =aTrack%vec%w%r(3)
+         o(Np)%zenith = aTrack%vec%coszenith
+         o(Np)%wgt = aTrack%wgt
+         o(Np)%user =  aTrack%user
 !     ===================================================
-         if(o(Np).code .eq. 3) then
-            user=aTrack.user
+         if(o(Np)%code .eq. 3) then
+            user=aTrack%user
             write(*, 959) 
 !     *  o(Np).where,   
 !     *  o(Np).code,   
 !     *  o(Np).charge,  
-     *  ( o(Np).erg - o(Np).mass ),   
+     *  ( o(Np)%erg - o(Np)%mass ),   
 !     *  ( o(Np).x ), ( o(Np).y ) ,  
 !     *  ( o(Np).wx ),  
 !     *  ( o(Np).wy ),  
@@ -277,16 +277,16 @@
       sumeh =0
 !         count sum Eg etc
       do i = 1, Np
-         if(o(i).where .eq. Where) then
-            if(o(i).code .le. kelec) then
+         if(o(i)%where .eq. Where) then
+            if(o(i)%code .le. kelec) then
                ng = ng + 1
-               sumeg = sumeg + o(i).erg
-            elseif( ( o(i).code .ge. kpion .and.
-     *                o(i).code .le. knuc )
+               sumeg = sumeg + o(i)%erg
+            elseif( ( o(i)%code .ge. kpion .and.
+     *                o(i)%code .le. knuc )
      *             .or.
-     *               o(i).code .eq. kgnuc) then
+     *               o(i)%code .eq. kgnuc) then
                nh = nh + 1
-               sumeh = sumeh + o(i).erg
+               sumeh = sumeh + o(i)%erg
             endif
          endif
       enddo
@@ -368,8 +368,8 @@
 !     atrack.pos.height      (vertical heigth from sea level)  
 !
 
-      h1 = TrackBefMove.pos.height- ObsSites(NoOfSites).pos.height
-      h2 = MovedTrack.pos.height - ObsSites(NoOfSites).pos.height
+      h1 = TrackBefMove%pos%height- ObsSites(NoOfSites)%pos%height
+      h2 = MovedTrack%pos%height - ObsSites(NoOfSites)%pos%height
 
       end
 !     ********************* this is the hook called when
@@ -411,24 +411,24 @@
       if(never .lt. 0) then
          Nproduced = 1
 !           IBM user must modify next
-         Pwork(1) = MovedTrack.p
+         Pwork(1) = MovedTrack%p
       endif
 
 !         high energy parent at node might be used
 !        for hybrid AS generation if it is in some
 !        energy region.
-      if( MovedTrack.p.code .eq. kelec ) then
-         if( MovedTrack.asflag .eq. 0 ) then
-            if( MovedTrack.p.fm.p(4) .lt. Ethresh ) then
-               MovedTrack.asflag = -1
+      if( MovedTrack%p%code .eq. kelec ) then
+         if( MovedTrack%asflag .eq. 0 ) then
+            if( MovedTrack%p%fm%p(4) .lt. Ethresh ) then
+               MovedTrack%asflag = -1
             endif
          endif
       endif
 
       call cmemoNode(Wdev, never, 2)
-      if(MovedTrack.asflag .eq. -1) then
+      if(MovedTrack%asflag .eq. -1) then
 !          decendent should not be used to  generae A.S
-         MovedTrack.asflag  = -2
+         MovedTrack%asflag  = -2
       endif
 
  10   continue
@@ -495,14 +495,14 @@
       if( bgevent ) then
 !               just  after collision or before 1st col.
 !               (knockon)   
-         yes = ( MovedTrack.p.code .eq. knuc .or.
-     *          MovedTrack.p.code .eq. kgnuc ) .and.
-     *          IntInfArray(ProcessNo).process .eq. 'coll'
+         yes = ( MovedTrack%p%code .eq. knuc .or.
+     *          MovedTrack%p%code .eq. kgnuc ) .and.
+     *          IntInfArray(ProcessNo)%process .eq. 'coll'
          if(yes)  then
 !               just after collision of nucleon or heavy primary
 
 !                copy particle property
-            incip = MovedTrack.p
+            incip = MovedTrack%p
 !               userE(2) is used to store  Xcm of a particle
 !               but the last bit is set if parent is pi/K
 !               else  it is reset to 0
@@ -511,12 +511,12 @@
             bgevent = .false.
             userI(1)=6
             userE(2) = 1.
-            MovedTrack.user =  user
+            MovedTrack%user =  user
             call cmkptc(6, 0, 1, tgt)
-            tgt.fm.p(1) = 0.
-            tgt.fm.p(2) = 0.
-            tgt.fm.p(3) = 0.
-            tgt.fm.p(4) = tgt.mass
+            tgt. fm%p(1) = 0.
+            tgt. fm%p(2) = 0.
+            tgt. fm%p(3) = 0.
+            tgt. fm%p(4) = tgt. mass
             pj = incip
             pjcm = pj
             call cirot3vec(1, incip, incip, pj)
@@ -530,14 +530,14 @@
             call cgetCurrentStackPos(stackpos)
 
             do i = stackpos-Nstacked+1, stackpos
-               aptcl=Stack(i).p
-               call cirot3vec(1, incip, Stack(i).p, aptcl)
+               aptcl=Stack(i)%p
+               call cirot3vec(1, incip, Stack(i)%p, aptcl)
                call cbst1(1, cmsptcl, aptcl, aptcl)
                call cyeta(aptcl, y, eta)
                userI(1)=eta*1000.
                userI(2)=y * 1000.
 !                    xcm
-               userE(2)= aptcl.fm.p(3)/pjcm.fm.p(3)
+               userE(2)= aptcl%fm%p(3)/pjcm%fm%p(3)
 !/////////////////
 !            if(aptcl.code .le. 5 .and. userE(2) .gt. -1.0) then
 !               write(*,'(a,3i3, 4g11.3)')  'p: ',  aptcl.code, 
@@ -546,13 +546,13 @@
 !            endif
 !/////////////////
 !                set ptcl code by using last bit
-               if(aptcl.code .le. 5) then
+               if(aptcl%code .le. 5) then
                   call ksetbit(userE(2), 1)
                else
                   call krsetbit(userE(2), 1)
                endif
 !                    store in stack
-               Stack(i).user=user
+               Stack(i)%user=user
 
             enddo
          endif
@@ -634,14 +634,14 @@
 !
       nlow = 0 
       do i = 1, Nproduced
-         ke = Pwork(i).fm.p(4) - Pwork(i).mass 
-         if( ( Pwork(i).code .le. kelec .and. 
+         ke = Pwork(i)%fm%p(4) - Pwork(i)%mass 
+         if( ( Pwork(i)%code .le. kelec .and. 
      *       ke .ge.  Cuteg ) .or. 
-     *       ( Pwork(i).code .gt. kelec .and.          
+     *       ( Pwork(i)%code .gt. kelec .and.          
      *       ke .ge.  Cutneg ) ) then
 !              count low energy ptcls
             if(flag .ne. -3) then
-               if( ke .lt.  KEminObs) then
+               if( ke .lt.  KEminObs(2) ) then
                   nlow = nlow + 1
                endif
             else
@@ -658,26 +658,26 @@
 !       if there is no return here, the size of skeleton data
 !       becomes 3.2 times larger
 
-      if(nlow .eq. 0  .and. MovedTrack.asflag .ne. -1) return
+      if(nlow .eq. 0  .and. MovedTrack%asflag .ne. -1) return
 
 
-      p.posx = MovedTrack.pos.xyz.r(1)
-      p.posy = MovedTrack.pos.xyz.r(2)
-      p.posz = MovedTrack.pos.xyz.r(3)
-      p.depth = MovedTrack.pos.depth
-      p.height = MovedTrack.pos.height
-      if( MovedTrack.pos.colheight .gt. 1.e36) then
-         p.colHeight = 1.e36    ! no col. yet.
+      p%posx = MovedTrack%pos%xyz%r(1)
+      p%posy = MovedTrack%pos%xyz%r(2)
+      p%posz = MovedTrack%pos%xyz%r(3)
+      p%depth = MovedTrack%pos%depth
+      p%height = MovedTrack%pos%height
+      if( MovedTrack%pos%colheight .gt. 1.e36) then
+         p%colHeight = 1.e36    ! no col. yet.
       else
-         p.colHeight =  MovedTrack.pos.colheight
+         p%colHeight =  MovedTrack%pos%colheight
       endif
-      p.atime = MovedTrack.t
-      p.where = MovedTrack.where
-      p.coszenith = MovedTrack.vec.coszenith
-      p.code = MovedTrack.p.code
-      p.erg  = MovedTrack.p.fm.p(4)
-      p.asflag = MovedTrack.asflag
-      p.user =  MovedTrack.user
+      p%atime = MovedTrack%t
+      p%where = MovedTrack%where
+      p%coszenith = MovedTrack%vec%coszenith
+      p%code = MovedTrack%p%code
+      p%erg  = MovedTrack%p%fm%p(4)
+      p%asflag = MovedTrack%asflag
+      p%user =  MovedTrack%user
 
 !c
 !c     *           p.posx, p.posy, p.posz, p.depth, p.height, 
@@ -695,20 +695,20 @@
       write(dev) nlow, p
 
       do i = 1, Nproduced
-         ke = Pwork(i).fm.p(4) - Pwork(i).mass 
-         if( ( Pwork(i).code .le. kelec .and. 
+         ke = Pwork(i)%fm%p(4) - Pwork(i)%mass 
+         if( ( Pwork(i)%code .le. kelec .and. 
      *       ke .ge.  Cuteg ) .or. 
-     *       ( Pwork(i).code .gt. kelec .and.          
+     *       ( Pwork(i)%code .gt. kelec .and.          
      *       ke .ge.  Cutneg ) ) then
-            if(flag .eq. -3 .or.  ke .lt. KEminObs) then
-               c.code = Pwork(i).code
-               c.subcode =  Pwork(i).subcode 
-               c.charge =  Pwork(i).charge
-               c.fm(1) = Pwork(i).fm.p(1)
-               c.fm(2) = Pwork(i).fm.p(2)
-               c.fm(3) = Pwork(i).fm.p(3)
-               c.fm(4) = Pwork(i).fm.p(4)
-               c.mass = Pwork(i).mass
+            if(flag .eq. -3 .or.  ke .lt. KEminObs(2)) then
+               c%code = Pwork(i)%code
+               c%subcode =  Pwork(i)%subcode 
+               c%charge =  Pwork(i)%charge
+               c%fm(1) = Pwork(i)%fm%p(1)
+               c%fm(2) = Pwork(i)%fm%p(2)
+               c%fm(3) = Pwork(i)%fm%p(3)
+               c%fm(4) = Pwork(i)%fm%p(4)
+               c%mass = Pwork(i)%mass
                if(bgevent .and. neporeg .eq. 3 ) then
                   aptcl = Pwork(i)
                   call cirot3vec(1, incip,  Pwork(i),  aptcl)
@@ -717,14 +717,14 @@
                   userI(1)=eta*1000.
                   userI(2)=y * 1000.
 !                    xcm
-                  userE(2)= aptcl.fm.p(3)/pjcm.fm.p(3)
+                  userE(2)= aptcl%fm%p(3)/pjcm%fm%p(3)
 !                     set ptcl code by using last bit
-                  if(Pwork(i).code .le. 5) then
+                  if(Pwork(i)%code .le. 5) then
                      call ksetbit(userE(2), 1)
                   else
                      call krsetbit(userE(2), 1)
                   endif
-                  c.user = user
+                  c%user = user
 !////////////////////
 !                  if(userE(2) .gt. -1. .and. 
 !     *              Pwork(i).code .le. 5) then
@@ -735,7 +735,7 @@
 !                  endif
 !/////////////////
                else
-                  c.user = p.user
+                  c%user = p%user
                endif
                write(dev) c
             endif
@@ -770,8 +770,8 @@
 
       write(to) cumnum, num, irevent,  Zfirst
       call cputHES(to)   ! put high energy showers.
-      write(0,*) ' first Z=',Zfirst.pos.depth*0.1, ' g/cm2',
-     *  Zfirst.pos.height, ' m' 
+      write(0,*) ' first Z=',Zfirst%pos%depth*0.1, ' g/cm2',
+     *  Zfirst%pos%height, ' m' 
       
       call cputNodInfo(from, to)  ! put nordal info.
 
