@@ -24,22 +24,22 @@
          write(*,'(a, 4i11)' ) 'h ', cumnum, num, ir
          write(*,'(a, i3,2i5,4x,g12.3,3x,f8.5,g12.3)')
      *    'f ',
-     *    zf.p.code, zf.p.subcode, zf.p.charge,
-     *    zf.p.fm.p(4), zf.vec.coszenith,
-     *    zf.pos.depth/10.
+     *    zf%p%code, zf%p%subcode, zf%p%charge,
+     *    zf%p%fm%p(4), zf%vec%coszenith,
+     *    zf%pos%depth/10.
 
          read(21) Np
          write(*,'(a, i6)' ) 'nob ', Np
          do i = 1, Np
             read(21) oo
-            user=oo.user
+            user=oo%user
             if( kbitest(userE(2), 1) ) then
                codex = 4
             else
                codex = 6
             endif
             write(*,'(g14.6, i3,3g11.3)') 
-     *         oo.erg, codex, userI(1)/1000.,  userI(2)/1000.,
+     *         oo%erg, codex, userI(1)/1000.,  userI(2)/1000.,
      *         userE(2)
 !            write(*,
 !        *      '(4i3, 1p4E11.3, 0p, 2f8.4,f10.6, i3, 1p g11.3)')
@@ -56,20 +56,20 @@
             if(nlow .gt. 0) then
                write(*,'(a,i8)') 'nl ', nlow
                if(nlow .gt. 0) then
-                  user = pp.user
+                  user = pp%user
                   write(*,'(a, 8g13.5,3i3,4g13.6)')
-     *                 'p ', pp.posx, pp.posy, pp.posz,pp.coszenith,
-     *                 pp.depth, pp.colHeight, 
-     *                 pp.height, pp.atime, pp.where, pp.code,
-     *                 pp.asflag, pp.erg, userI(1)/1000., 
+     *                 'p ', pp%posx, pp%posy, pp%posz,pp%coszenith,
+     *                 pp%depth, pp%colHeight, 
+     *                 pp%height, pp%atime, pp%where, pp%code,
+     *                 pp%asflag, pp%erg, userI(1)/1000., 
      *                 userI(2)/1000., userE(2)
                   do i = 1, nlow
                      read(21) cc
-                     user = cc.user
+                     user = cc%user
                      write(*,'(a, 3i3,5g13.6, 3g11.3)')
-     *                    'c ', cc.code, cc.subcode, cc.charge, 
-     *                    cc.fm(1), cc.fm(2),cc.fm(3), cc.fm(4),
-     *                    cc.mass, userI(1)/1000., userI(2)/1000.,
+     *                    'c ', cc%code, cc%subcode, cc%charge, 
+     *                    cc%fm(1), cc%fm(2),cc%fm(3), cc%fm(4),
+     *                    cc%mass, userI(1)/1000., userI(2)/1000.,
      *                    userE(2)
                   enddo
                endif
