@@ -10,15 +10,15 @@
 !                 K     0         1
 !                 p     1         0
 !             pbar/nbar 1         1 
-       if( p.code .eq. 4 ) then
+       if( p%code .eq. 4 ) then
           call krsetbit(code, 1)
           call krsetbit(code, 2)
-       elseif(p.code .eq. 5) then
+       elseif(p%code .eq. 5) then
           call ksetbit(code, 1)
           call krsetbit(code, 2)
-       elseif( (p.code .eq. 6 .and. p.charge .eq. -1 ) .or.
-     *         (p.code .eq. 6 .and. p.charge .eq. 0 .and.
-     *          p.subcode .eq. antip ) ) then
+       elseif( (p%code .eq. 6 .and. p%charge .eq. -1 ) .or.
+     *         (p%code .eq. 6 .and. p%charge .eq. 0 .and.
+     *          p%subcode .eq. antip ) ) then
           call ksetbit(code, 1)
           call ksetbit(code, 2)
        else
