@@ -1,6 +1,6 @@
 #include "cmain.f"
 #include "chookHybAS.f"
-#include "ctemplCeren.f"
+!!! #include "ctemplCeren.f" not needed now
 !     NOTE:  chookEInt and chookGInt should not be used as of 
 !            version uv0.64001    
 !
