@@ -10,8 +10,8 @@
             real*8  Espace(7),  Ecrash(7)
             real*8  MaxEbreak(2), MaxRelEbreak(2)
             real*8  SumEdiff, SumAbsEdiff 
-            record /track/ inci
-            record /coord/ angle
+            type(track):: inci
+            type(coord):: angle
             common /Zabsob/  inci, angle,
      *      dEbydEdx, dEbyDeath, dEbyDeathG, dEbyDeathE, dEbyDeathMuPiK,
      *      dEbyDeathNeu, dEbyDeathP, dEbyDeathO, deByDeathNut, Espace,
