@@ -1,4 +1,6 @@
       subroutine xBgRun
+      use modHistogram
+      use modHistogram1
       implicit none
 #include  "Zmaxdef.h"
 #include "Zglobalc.h"
@@ -44,25 +46,27 @@
       integer klena
       integer w2hl(MaxNoOfSites)
       real*8 r, Eloss, rinmu, cosang
-      real*8 dedt, dedtF, rho, dist, disto, BinFai
+      real*8 dedt, dedtF, rho, dist, disto
+      real(8):: BinFai=30.0
       real*8 aa
       real*8 wx, wy, wz, temp
       real   za
       real  de, Ek, f, molu
       real  dt, tmin 
-      real*8  cvh2den
-      data BinFai/30./
+
+      real(8),external:: cvh2den
+
+      
       integer ldep
 !     integer ndummy
-      character*9 ptcln(4)
-      data ptcln/"Photons", "Electrons","Muons", "hadron"/
-      character*9 ptcl2(3)
-      data ptcl2/"Electrons", "Muons","All"/
-      real power(4)
+      character(9)::
+     *   ptcln(4)=(/"Photons", "Electrons","Muons", "hadron"/)
+      character(9):: ptcl2(3)=(/"Electrons", "Muons","All"/)
+      real(4)::power(4) =(/1.,1.,1., 1./)
       integer nstr
-      data power/1.,1.,1., 1./
-      real  power2(3)
-      data power2/1.,1.,1./
+
+      real(4):: power2(3)=(/1.,1.,1./)
+
       character*128 title
       character*96 evid(nsites)
       save evid
@@ -117,27 +121,27 @@
       entry xBgEvent
 
       call cqIncident(inci, angle)
-      E0 = inci.p.fm.p(4)
-      if(inci.p.code .eq. kmuon) then
+      E0 = inci%p%fm%p(4)
+      if(inci%p%code .eq. kmuon) then
          call csetMuonPol(1.0d0)
       endif
-      cosz = -angle.r(3)
-      fai0 = atan2(-angle.r(2), -angle.r(1))*Todeg
+      cosz = -angle%r(3)
+      fai0 = atan2(-angle%r(2), -angle%r(1))*Todeg
       sint = sqrt(1.0-cosz**2)
 
-      if(inci.p.code .eq. 9) then
-         NN= inci.p.subcode
-      elseif(inci.p.code .eq. 1) then
+      if(inci%p%code .eq. 9) then
+         NN= inci%p%subcode
+      elseif(inci%p%code .eq. 1) then
          NN=0
       else
          NN=1
       endif
 
       write(0,'("i ",  i6,  i4, g13.4,3f11.7,f7.1)')
-     *   EventNo, inci.p.code,
-     *   inci.p.fm.e,  -angle.r(1),  -angle.r(2), -angle.r(3)
+     *   EventNo, inci%p%code,
+     *   inci%p%fm%e,  -angle%r(1),  -angle%r(2), -angle%r(3)
        write(0,'(a, 1p, 6g15.5)')
-     *    '### ', DetXaxis.r(1:3), DetZaxis.r(1:3)
+     *    '### ', DetXaxis%r(1:3), DetZaxis%r(1:3)
       do i = 1, NoOfSites
          SumEloss(i) = 0.
          do j = 1, 4
@@ -162,7 +166,7 @@
       
       do i = 1, ansites
          ldep = histdep(i)
-         call cminTime2WebSec(ObsSites(ldep).pos.xyz,
+         call cminTime2WebSec(ObsSites(ldep)%pos%xyz,
      *        ldep, i,  webmin )
       enddo
 
@@ -220,7 +224,7 @@
      *                 rmin, bin, nrbin,  b'00011' )
                   call kwhistai(rspec(j, ifai, i), 
      *            "Lateral Dist. of "//ptcln(j)//" at  diff. azimuth",
-     *            "ar", "ptcls", .true.,  power(j),   "r", "m.u")
+     *            "ar", "ptcls", .true.,  power(j),   "r", "m%u")
 !                     clear
                   call  kwhistc( rspec(j, ifai, i) )
                enddo
@@ -242,47 +246,47 @@
       if(mod(obstimes, 100000.d0) .eq. 0. ) then 
          dosort=.false.
          do i = 1, min(4,Stack_pos)
-            if(Stack(i).p.fm.p(4) .ne. Savederg(i)) then
-               Savederg(i)=Stack(i).p.fm.p(4) 
+            if(Stack(i)%p%fm%p(4) .ne. Savederg(i)) then
+               Savederg(i)=Stack(i)%p%fm%p(4) 
                dosort=.true.
             endif
          enddo
          if(dosort) then
             call csortStack
          endif
-         write(0, *) ' obstimes=', obstimes, ' ptclE=',aTrack.p.fm.p(4)
+         write(0, *) ' obstimes=', obstimes, ' ptclE=',aTrack%p%fm%p(4)
          do i = 1, min(4,Stack_pos)
-            write(0,*)' stack tops=', Stack(i).p.fm.p(4)
+            write(0,*)' stack tops=', Stack(i)%p%fm%p(4)
          enddo
       endif
 !     ***************
-      code = aTrack.p.code
-      ldep =  aTrack.where
+      code = aTrack%p%code
+      ldep =  aTrack%where
 !     ************
       if(id .eq. 2 .and. code .le. 6 ) then  ! neglect rare ptcls
-         wz = aTrack.vec.w.r(3) ! downgoing < 0
+         wz = aTrack%vec%w%r(3) ! downgoing < 0
          if(wz .gt. 0) return
          wz = -wz
-         r = sqrt( aTrack.pos.xyz.x**2 +
-     *                 aTrack.pos.xyz.y**2 )
-         molu = ObsSites(ldep).mu
+         r = sqrt( aTrack%pos%xyz%x**2 +
+     *                 aTrack%pos%xyz%y**2 )
+         molu = ObsSites(ldep)%mu
          rinmu =r/molu
          sr = rinmu   ! single precision
          ridx = (log10( rinmu/rmin )/bin +0.5) +1 
 
-         Ek = aTrack.p.fm.p(4) -aTrack.p.mass
-         wt = aTrack.wgt  ! wt is single
+         Ek = aTrack%p%fm%p(4) -aTrack%p%mass
+         wt = aTrack%wgt  ! wt is single
          if(code .eq. kphoton) then
-            Ng(ldep) = Ng(ldep) + aTrack.wgt
+            Ng(ldep) = Ng(ldep) + aTrack%wgt
          elseif(code .eq. kelec) then
-            Ne(ldep) = Ne(ldep) + aTrack.wgt
+            Ne(ldep) = Ne(ldep) + aTrack%wgt
          elseif(code .eq. kmuon) then
-            Nmu(ldep) = Nmu(ldep) + aTrack.wgt
+            Nmu(ldep) = Nmu(ldep) + aTrack%wgt
          elseif(code .le. 6) then
-            Nhad(ldep) = Nhad(ldep) +aTrack.wgt
+            Nhad(ldep) = Nhad(ldep) +aTrack%wgt
          endif
 !            ---------- compute energy loss 
-         if(aTrack.p.charge .ne. 0  ) then
+         if(aTrack%p%charge .ne. 0  ) then
 !             -----------------
 !                      /|    |
 !                     / |   1g/cm2 
@@ -309,18 +313,18 @@
 !                     loss.  We may better use full here.
 !                       energy in 1 g/cm2 of vertical direction
             Eloss =min( real(dedtF*dist), Ek)   !  GeV/(g/cm2)
-            Eloss = Eloss*aTrack.wgt !  GeV/(g/cm2)
+            Eloss = Eloss*aTrack%wgt !  GeV/(g/cm2)
             SumEloss(ldep)=SumEloss(ldep) + Eloss
          else
             Eloss=0.
          endif
 
          if(code .ge. 4) code=4
-         if( aTrack.p.charge .ne. 0   .or. 
+         if( aTrack%p%charge .ne. 0   .or. 
      *       w2hl(ldep) .gt. 0 ) then 
 !                  fai
 !              fai is  in    -15 to 345  (for dfai=30.)                                     
-            aa=atan2(aTrack.pos.xyz.y, aTrack.pos.xyz.x)*
+            aa=atan2(aTrack%pos%xyz%y, aTrack%pos%xyz%x)*
      *        Todeg -fai0
             fai = aa/Todeg
             aa= mod(aa + 360.d0,   360.d0)
@@ -345,7 +349,7 @@
                endif
 
                if( tkrtspec ) then
-                  stime =  aTrack.t 
+                  stime =  aTrack%t 
                   if(reducedTime .eq. 1) then
                      delta =  r*(cos(fai) + 1.)*sint*1.d9/c ! ns
                      stime = stime + delta
@@ -395,8 +399,8 @@
                dd =(ASDepthList(NoOfASSites) -
      *              ASDepthList(NoOfASSites-1))
             endif
-            cog = cog + ASObsSites(i).esize*dd*ASDepthList(i)
-            sumne= sumne +ASObsSites(i).esize*dd
+            cog = cog + ASObsSites(i)%esize*dd*ASDepthList(i)
+            sumne= sumne +ASObsSites(i)%esize*dd
          enddo
 !          0.1 is for g/cm2
          cog = cog*0.1/sumne
@@ -404,8 +408,8 @@
          cog2 = 0.
          sumne = 0.
          do i = 1, NoOfASSites
-            if( ASObsSites(i).age .gt.
-     *          (2.0-ASObsSites(NoOfASSites).age))  then
+            if( ASObsSites(i)%age .gt.
+     *          (2.0-ASObsSites(NoOfASSites)%age))  then
                if(i .gt. 1 .and. i  .lt. NoOfASSites ) then
                   dd =( ASDepthList(i+1) - ASDepthList(i-1))/2.0
                elseif(i .eq. 1) then
@@ -415,8 +419,8 @@
      *              ASDepthList(NoOfASSites-1))
                endif
                dd = dd
-               cog2 = cog2 + ASObsSites(i).esize*ASDepthList(i)*dd
-               sumne= sumne +ASObsSites(i).esize*dd
+               cog2 = cog2 + ASObsSites(i)%esize*ASDepthList(i)*dd
+               sumne= sumne +ASObsSites(i)%esize*dd
             endif
          enddo
          if(sumne .gt. 0.) then
@@ -432,9 +436,9 @@
          write(fnoB,
      *   '("h ", i4,  3i3, 1pE11.3, 0p 3f11.7, 1pE11.3, 0p,
      *     2f7.0,i2,a )')
-     *      EventNo,  inci.p.code,
-     *      inci.p.subcode, inci.p.charge,
-     *      inci.p.fm.e, -angle.r(1), -angle.r(2), -angle.r(3),
+     *      EventNo,  inci%p%code,
+     *      inci%p%subcode, inci%p%charge,
+     *      inci%p%fm%e, -angle%r(1), -angle%r(2), -angle%r(3),
      *      firstcdepth, cog, cog2, vn, ' /'
 
          sumEbydEdx = 0.
@@ -455,10 +459,10 @@
                write(fnoB, '("t ", i3, 2f7.1,  2f6.3,
      *         1p14g12.3 )')
      *           i, 
-     *          ASDepthList(i)*0.1,  ASObsSites(i).mu,
-     *          ASObsSites(i).age,   ASDepthList(i)*0.1/cog2, 
+     *          ASDepthList(i)*0.1,  ASObsSites(i)%mu,
+     *          ASObsSites(i)%age,   ASDepthList(i)*0.1/cog2, 
      *          Ng(i), Ne(i), Nmu(i), Nhad(i),
-     *          ASObsSites(i).esize, SumEloss(i), 
+     *          ASObsSites(i)%esize, SumEloss(i), 
      *          dEbydEdx(i), dEbyDeath(i), 
 !                   next ones are from 7.51
      *          dEbyDeathG(i),  dEbyDeathE(i), dEbyDeathMuPiK(i), 
@@ -482,10 +486,10 @@
                write(fnoB, '("t ", i3, 2f7.1,  2f6.3,
      *         1p6E11.3 )')
      *           i, 
-     *          ASDepthList(i)*0.1,  ASObsSites(i).mu,
-     *          ASObsSites(i).age,   ASDepthList(i)*0.1/cog2, 
+     *          ASDepthList(i)*0.1,  ASObsSites(i)%mu,
+     *          ASObsSites(i)%age,   ASDepthList(i)*0.1/cog2, 
      *          Ng(i), Ne(i), Nmu(i), Nhad(i),
-     *          ASObsSites(i).esize, SumEloss(i)
+     *          ASObsSites(i)%esize, SumEloss(i)
             endif
          enddo
          if(Eabsorb(1) .ne. 0) then
@@ -499,7 +503,7 @@
             write(fnoB,
      *       '("c ",1p7E11.3)' ) 
      *      MaxEbreak, MaxRelEbreak, SumEdiff, SumAbsEdiff,
-     *      MaxEbreak(1)/inci.p.fm.p(4)
+     *      MaxEbreak(1)/inci%p%fm%p(4)
 
             sumMissing =  sumEcrash + sumEspace + sumEbyDeathNeu
             sumUncertain = sumEbyDeathNut
@@ -532,13 +536,13 @@
      *   '(i3, i5,  f5.2, f5.2,
      *   f7.1,  i4)')
      *   histdep(i), int( ASDepthList(j)*0.1 ),  
-     *   ASObsSites(j).age, ASDepthList(j)*0.1/cog2,
-     *   ASObsSites(j).mu, int(cog2)
+     *   ASObsSites(j)%age, ASDepthList(j)*0.1/cog2,
+     *   ASObsSites(j)%mu, int(cog2)
       enddo
 #if defined  (MACOSX)
 #else
       if(tkarspec) then
-         filename = basefilename2(1:klena(basefilename2))//"-r.hist"
+         filename = basefilename2(1:klena(basefilename2))//"-r%hist"
          call copenfw2(fnoL, filename, binw, icon)
         do i = 1, ansites
             k=histdep(i)
@@ -563,7 +567,7 @@
       endif
 
       if( tkrtspec ) then
-         filename = basefilename2(1:klena(basefilename2))//"-t.hist"
+         filename = basefilename2(1:klena(basefilename2))//"-t%hist"
          call copenfw2(fnoT, filename, binw, icon)
 
          do i = 1, ansites
