@@ -89,7 +89,7 @@
       integer cumnum, num, jeof, fin
       read( Mdev, end=1000, err=999 ) cumnum, num, SeedSave,Zfirst
 
-      write(*,*) ' Zfirst=',Zfirst.pos.depth
+      write(*,*) ' Zfirst=',Zfirst%pos%depth
 
       EventsInTheRun = EventsInTheRun + 1
       EventNo = EventNo + 1
@@ -148,7 +148,7 @@
       type(track):: aTrack
 !
 !
-       write(*,*) 'o ', aTrack.p.code, aTrack.p.fm.p(4)
+       write(*,*) 'o ', aTrack%p%code, aTrack%p%fm%p(4)
 !      call xObs(aTrack, id)
 
 
@@ -222,8 +222,8 @@
 !     atrack.pos.height      (vertical heigth from sea level)  
 !
 
-      h1 = TrackBefMove.pos.height- ObsSites(NoOfSites).pos.height
-      h2 = MovedTrack.pos.height - ObsSites(NoOfSites).pos.height
+      h1 = TrackBefMove%pos%height- ObsSites(NoOfSites)%pos%height
+      h2 = MovedTrack%pos%height - ObsSites(NoOfSites)%pos%height
 
       end
 !     ********************* this is the hook called when
@@ -265,8 +265,8 @@
       do i = 1, Np
          read(from) o(i)
          write(*,'(a, 4i3, 1pE11.3)' ) ' HE ',
-     *          o(i).where, o(i).code, o(i).subcode, o(i).charge,
-     *          o(i).erg
+     *          o(i)%where, o(i)%code, o(i)%subcode, o(i)%charge,
+     *          o(i)%erg
       enddo
       end
 
@@ -282,19 +282,19 @@
       integer i
 
       do i = 1, Np
-         aTrack.where =  o(i).where 
-         aTrack.p.code =  o(i).code 
-         aTrack.p.subcode = o(i).subcode 
-         aTrack.p.charge = o(i).charge 
-         aTrack.t = o(i).atime 
-         aTrack.p.fm.p(4) = o(i).erg
-         aTrack.p.mass = o(i).mass 
-         aTrack.pos.xyz.r(1) = o(i).x 
-         aTrack.pos.xyz.r(2) = o(i).y 
-         aTrack.vec.w.r(1) = o(i).wx
-         aTrack.vec.w.r(2) = o(i).wy
-         aTrack.vec.w.r(3) = o(i).wz
-         aTrack.vec.coszenith = o(i).zenith 
+         aTrack%where =  o(i)%where 
+         aTrack%p%code =  o(i)%code 
+         aTrack%p%subcode = o(i)%subcode 
+         aTrack%p%charge = o(i)%charge 
+         aTrack%t = o(i)%atime 
+         aTrack%p%fm%p(4) = o(i)%erg
+         aTrack%p%mass = o(i)%mass 
+         aTrack%pos%xyz%r(1) = o(i)%x 
+         aTrack%pos%xyz%r(2) = o(i)%y 
+         aTrack%vec%w%r(1) = o(i)%wx
+         aTrack%vec%w%r(2) = o(i)%wy
+         aTrack%vec%w%r(3) = o(i)%wz
+         aTrack%vec%coszenith = o(i)%zenith 
          call chookObs(aTrack, 2)
       enddo
       end
@@ -327,8 +327,8 @@
          call cpop(tt(i), remain)
       enddo
       do i = NoOfLowE, 1, -1
-         write(*,* ) 'LE ', tt(i).p.code, tt(i).p.charge, 
-     *   tt(i).p.fm.p(4)-tt(i).p.mass, tt(i).p.mass
+         write(*,* ) 'LE ', tt(i)%p%code, tt(i)%p%charge, 
+     *   tt(i)%p%fm%p(4)-tt(i)%p%mass, tt(i)%p%mass
       enddo
       call cinitStack           ! empty the stack
       end
