@@ -1,16 +1,23 @@
 #!/bin/sh
+# icr 32
+#source /tibet/work/kasahara/intel/ifc/ifortvars.sh ia32
+#source /tibet/work/kasahara/intel/icc/ifortvars.sh ia32
+# icr 64
+source  /tibet/work/kasahara/intel/ifc/ifortvars.sh intel64
+source  /tibet/work/kasahara/intel/icc/iccvars.sh intel64
+
 #    tasim 32 bit
 #  source  /Loft1/Intel/ifc/bin/ifortvars.sh
 #  source  /Loft1/Intel/icc/bin/iccvars.sh
 #   waseda 32 bit
-  source  /opt/intel/ifc/bin/ifortvars.sh
-  source  /opt/intel/icc/iccvars_ia32.sh
+#  source  /opt/intel/ifc/bin/ifortvars.sh
+#  source  /opt/intel/icc/iccvars_ia32.sh
 #    waseda intel 64 bit
 #  source   /opt/intel/ifce/ifortvars_intel64.sh
 #  source  /opt/intel/icce/iccvars_intel64.sh
 
 
-export COSMOSTOP=/home/Users/kasahara/Cosmos7.51
+export COSMOSTOP=~/Cosmos
 export COSMOSINC=$COSMOSTOP/cosmos
 export PATH=$COSMOSTOP/Scrpt:$PATH
 # export GXX_ROOT=/usr/lib/gcc/i486-linux-gnu/4.3.3/
@@ -38,3 +45,5 @@ fi
 #  next msg may come out depending on icc
 #icc: command line remark #10010: option '-prof-genx' is deprecated
 #  and will be removed in a future release. See '-help deprecated'
+
+
