@@ -1,6 +1,6 @@
 #include "cmain.f"
 #include "chookHybAS.f"
-#include "ctemplCeren.f"
+!!! #include "ctemplCeren.f" not needed now
 !  *************************************** hook for Beginning of a Run
 !  * At this moment, all (system-level) initialization for this run
 !  * has been ended.  After this routine is executed, the system goes into the
@@ -41,7 +41,7 @@
       implicit none
 #include "Zmanagerp.h"
       integer sig, code, context(5)
-      write(ErrorOut, *)  ' f.p exception content=' , context(4)
+      write(ErrorOut, *)  ' f%p exception content=' , context(4)
 !      call abort()
       end
 #endif
@@ -148,8 +148,8 @@
 !     atrack.pos.height      (vertical heigth from sea level)  
 !
 
-      h1 = TrackBefMove.pos.height- ObsSites(NoOfSites).pos.height
-      h2 = MovedTrack.pos.height - ObsSites(NoOfSites).pos.height
+      h1 = TrackBefMove%pos%height- ObsSites(NoOfSites)%pos%height
+      h2 = MovedTrack%pos%height - ObsSites(NoOfSites)%pos%height
 
       end
 
@@ -242,26 +242,26 @@
       type(ptcl):: proj
       real(8):: pz 
  
-      if(  IntInfArray(ProcessNo).process /= 'coll' ) then  ! even if this is absent, OK
+      if(  IntInfArray(ProcessNo)%process /= 'coll' ) then  ! even if this is absent, OK
          return                                             ! ;inside cutptcl same is done
       endif
 
 !       first make Z axis as the incident particle
       do i = 1, Nproduced
-         call cirot3vec(i, MovedTrack.p.fm, Pwork(i).fm, Pwork(i).fm)
+         call cirot3vec(i, MovedTrack%p%fm, Pwork(i)%fm, Pwork(i)%fm)
       enddo
 
 !           make projectile move +z direction
 !        with the same energy as MovedTrack.p
-      proj =  MovedTrack.p
-      pz =sqrt( dot_product(proj.fm.p(1:3), proj.fm.p(1:3)) )
-      proj.fm.p(1:3) =(/0.d0, 0.d0, pz/)
+      proj =  MovedTrack%p
+      pz =sqrt( dot_product(proj%fm%p(1:3), proj%fm%p(1:3)) )
+      proj%fm%p(1:3) =(/0.d0, 0.d0, pz/)
       call cutptcl(proj)
 
 !          again convert Z axis to be the one where
 !       MovedTrack is defined
       do i = 1, Nproduced
-         call crot3vec( MovedTrack.p.fm, Pwork(i).fm, Pwork(i).fm )
+         call crot3vec( MovedTrack%p%fm, Pwork(i)%fm, Pwork(i)%fm )
       enddo
       never = 0
       end
