@@ -1,35 +1,35 @@
 
       module SoftenPiK
-c         This part is common to Cosmos(modifyX) and Cosmos/Util/Gencol
-c     Used to soften the x-distribution.     
+!         This part is common to Cosmos(modifyX) and Cosmos/Util/Gencol
+!     Used to soften the x-distribution.     
       implicit none
 
-c         The parameters are listed above the --------------- line
-c mode=0)      don't do any cut/modification of X
-c mode=1)      discard all pi/K with x>xth. 
-c              However, if the incident is pi/K the highest
-c              energy pi/K, resp, is untouched.
-c mode=2)      discard only pi0 with x> xth
-c mode=3)      soften pi/K/eta  spectrum; 
-c              If their x is >  x>xth, this is applied.
-c              (except for the leading pi/K when
-c              incident is pi/K).
-c mode=-3      probability of softening depends on the user's algorithm
-c              The user must modify cJudegeSplit.
-c    trial version method          
-c              If we find a pi/K/eta with x>xth,
-c              apply softening with the prob. of (x-xth)**a (a=0.1 default).
-c              Softening is done by splitting  the particle into two by
-c              calling csplitMeson.  The sum of two particle is made to
-c              be the same as the original particle. However, momentum 
-c              cannot be conserved: the two particle will have the same
-c              Pt as the original one and 3 memeta are adjuested to 
-c              satisfy P^2 + m^2 =E^2. Let the two particles' energy be
-c              E1 and E2.  If E2>E1, we split E2 into two again.
-c             (At present, if E1> E2, we don't  split E1). 
-c              (so, x>xth pi/K/eta may split into two or three).
-c            This method results in some unnatural small bump at x<xth.
-c
+!         The parameters are listed above the --------------- line
+! mode=0)      don't do any cut/modification of X
+! mode=1)      discard all pi/K with x>xth. 
+!              However, if the incident is pi/K the highest
+!              energy pi/K, resp, is untouched.
+! mode=2)      discard only pi0 with x> xth
+! mode=3)      soften pi/K/eta  spectrum; 
+!              If their x is >  x>xth, this is applied.
+!              (except for the leading pi/K when
+!              incident is pi/K).
+! mode=-3      probability of softening depends on the user's algorithm
+!              The user must modify cJudegeSplit.
+!    trial version method          
+!              If we find a pi/K/eta with x>xth,
+!              apply softening with the prob. of (x-xth)**a (a=0.1 default).
+!              Softening is done by splitting  the particle into two by
+!              calling csplitMeson.  The sum of two particle is made to
+!              be the same as the original particle. However, momentum 
+!              cannot be conserved: the two particle will have the same
+!              Pt as the original one and 3 memeta are adjuested to 
+!              satisfy P^2 + m^2 =E^2. Let the two particles' energy be
+!              E1 and E2.  If E2>E1, we split E2 into two again.
+!             (At present, if E1> E2, we don't  split E1). 
+!              (so, x>xth pi/K/eta may split into two or three).
+!            This method results in some unnatural small bump at x<xth.
+!
 
       integer,save:: mode = 3      
       real(8),save:: xth = 0.05    ! over this x, we apply cut  or modification
@@ -106,7 +106,7 @@ c
 !             next one is about 0.6 of maxn in Epics/Util/Gencol/Zprivate.h
 !             but this  cannot inherit maxn
       integer,parameter::half=12000  
-c--------------------------------------------------------------------
+!--------------------------------------------------------------------
 
       contains
 
@@ -114,7 +114,7 @@ c--------------------------------------------------------------------
       implicit none
 !         judge if this x should be split
 #include "Zptcl.h"
-      record /ptcl/ pj    ! input. projectile. you may use this
+      type(ptcl):: pj    ! input. projectile. you may use this
       real(8),intent(in):: x  ! KE ratio
       logical,intent(out):: split  ! .true.  or .false.. if true, split meson
 
@@ -139,20 +139,20 @@ c--------------------------------------------------------------------
       end     subroutine cJudgeSplit
       
       subroutine csoftenPiK(inciptcl, pstore, nin, nout)
-c         inciptcl made a collsion and generated nin particles in pstore
-c         particle information may be at CMS or Lab.
-c     If we want to  make the x-dist. softer,
-c      A) For Cosmos (air target),  we may use the Lab system
-c         (for large X, the distribution would be the same 
-c           as CMS)
+!         inciptcl made a collsion and generated nin particles in pstore
+!         particle information may be at CMS or Lab.
+!     If we want to  make the x-dist. softer,
+!      A) For Cosmos (air target),  we may use the Lab system
+!         (for large X, the distribution would be the same 
+!           as CMS)
       implicit none
 #include  "Zcode.h"
 #include  "Zptcl.h"
 #include  "Zmanagerp.h"
-      record /ptcl/inciptcl  ! input. incident ptcl at collision
-c                  
+      type(ptcl):: inciptcl  ! input. incident ptcl at collision
+!                  
       integer,intent(in)::nin ! # of ptcls in pstore 
-      record /ptcl/pstore(*)  ! input/output.   ptcls to be softened.
+      type(ptcl):: pstore(*)  ! input/output.   ptcls to be softened.
                            !     Softened ones are put here
       integer,intent(out)::nout ! # of ptcls re-stored in pstore 
       logical,save::first=.true.
@@ -164,10 +164,10 @@ c
       
       if( first ) then
          call copenf(TempDev, 
-     *       "$COSMOSTOP/UserHook/modifyX/softenparam.dat", jcon)
+     *       "$COSMOSTOP/UserHook/modifyX/softenparam%dat", jcon)
          if( jcon /= 0 ) then
             write(0,*) 'Data file for csoftenPiK could not be found'
-            write(0,*) 'in $COSMOSTOP/Util/Data/softenpiK.dat'
+            write(0,*) 'in $COSMOSTOP/Util/Data/softenpiK%dat'
             write(0,*) 'Forgot to set COSMOSTOP ?'
             stop
          else
@@ -204,25 +204,25 @@ c
 
 
       subroutine csoftenPiK0(inciptcl, pstore, nin, nout, exist)
-c         inciptcl made a collision and generated nin particles in pstore
-c         particle.  information may be at CMS or Lab.
-c     If we want to  make the x-dist. softer,
-c      A) For Cosmos (air target),  we may use the Lab system
-c         (for large X, the distribution would be the same 
-c           as CMS)
+!         inciptcl made a collision and generated nin particles in pstore
+!         particle.  information may be at CMS or Lab.
+!     If we want to  make the x-dist. softer,
+!      A) For Cosmos (air target),  we may use the Lab system
+!         (for large X, the distribution would be the same 
+!           as CMS)
       implicit none
 #include  "Zcode.h"
 #include  "Zptcl.h"
 
-      record /ptcl/inciptcl  ! input. incident ptcl at collision
-c                  
+      type(ptcl):: inciptcl  ! input. incident ptcl at collision
+!                  
       integer,intent(in)::nin ! # of ptcls in pstore 
-      record /ptcl/pstore(*)  ! input/output.   ptcls to be softened.
+      type(ptcl):: pstore(*)  ! input/output.   ptcls to be softened.
                            !     Softened ones are put here
       integer,intent(out)::nout ! # of ptcls re-stored in pstore 
       integer,intent(out)::exist  ! # of particcls with X> Xth
-C ----------------------------------------------
-      record /ptcl/work(2)
+! ----------------------------------------------
+      type(ptcl):: work(2)
       logical  ok
       integer::maxi
       real(8)::maxE
@@ -234,32 +234,32 @@ C ----------------------------------------------
       integer:: nw, icon
       logical:: split 
 
-      E0 = inciptcl.fm.p(4) - inciptcl.mass
+      E0 = inciptcl%fm%p(4) - inciptcl%mass
       nout = nin
       exist = 0
       if( E0lab < E0th) return      !!!!!
       nc = nin
-c            if pi/K is incident, regards the highest one as leading
-c            and avoid to modify 
-      if(leadingPiK .and. (inciptcl.code == kpion .or.
-     *     inciptcl.code == kkaon ) ) then
-c              find max energy ptcl index and E; eta cannot be incident
-         call cgetmaxptcl(pstore, nc, inciptcl.code, inciptcl.charge,
+!            if pi/K is incident, regards the highest one as leading
+!            and avoid to modify 
+      if(leadingPiK .and. (inciptcl%code == kpion .or.
+     *     inciptcl%code == kkaon ) ) then
+!              find max energy ptcl index and E; eta cannot be incident
+         call cgetmaxptcl(pstore, nc, inciptcl%code, inciptcl%charge,
      *        maxi, maxE)
       else
          maxi = 0
       endif
 
       do i = 1, nin
-         x = (pstore(i).fm.p(4)-pstore(i).mass)/E0
+         x = (pstore(i)%fm%p(4)-pstore(i)%mass)/E0
          if( abs(mode) == 3 ) then
             if( i /= maxi ) then
-c                softening
+!                softening
                if(x > xth ) then
 !                  modify high X of pi/K/eta
-                  if(pstore(i).code == kpion .or.
-     *                 pstore(i).code == kkaon 
-     *                 .or.   pstore(i).code ==  keta ) then
+                  if(pstore(i)%code == kpion .or.
+     *                 pstore(i)%code == kkaon 
+     *                 .or.   pstore(i)%code ==  keta ) then
                      nw = 0
                      exist = exist + 1
 !                       judge to split this
@@ -272,11 +272,11 @@ c                softening
                      ! split;  if impossilbe, do nothing
                         nw = nw + 1
                         work(nw) = pstore(i)
-                        work(nw).fm.p(4) = E1 + work(nw).mass 
+                        work(nw)%fm%p(4) = E1 + work(nw)%mass 
                         call cae2p(work(nw)) ! adjust momentum
                         nw = nw + 1
                         work(nw) = pstore(i)
-                        work(nw).fm.p(4) = E2 + work(nw).mass 
+                        work(nw)%fm%p(4) = E2 + work(nw)%mass 
                         call cae2p(work(nw))
 !                       original one is replaced by E1
                         pstore(i) = work(1)
@@ -291,32 +291,32 @@ c                softening
             endif
          elseif( mode == 1 ) then
             if( i /= maxi ) then
-c               discard all pi/K/eta with x>xth (except leanding)
-               if(pstore(i).code == kpion .or. pstore(i).code == kkaon 
-     *              .or.   pstore(i).code ==  keta ) then
+!               discard all pi/K/eta with x>xth (except leanding)
+               if(pstore(i)%code == kpion .or. pstore(i)%code == kkaon 
+     *              .or.   pstore(i)%code ==  keta ) then
                   if( x > xth ) then
-c                   to neglect, put mass as E
-                     pstore(i).fm.p(4) = pstore(i).mass
-                     pstore(i).fm.p(1:3) = 0.
+!                   to neglect, put mass as E
+                     pstore(i)%fm%p(4) = pstore(i)%mass
+                     pstore(i)%fm%p(1:3) = 0.
                      modified = .true.
                   endif
                endif
             endif
          elseif( mode == 2 ) then 
             if( i /= maxi) then
-c              discard only pi0/eta
-               if( ( pstore(i).code == kpion .and.
-     *              pstore(i).charge  == 0 ) .or.
-     *              pstore(i).code == keta ) then
+!              discard only pi0/eta
+               if( ( pstore(i)%code == kpion .and.
+     *              pstore(i)%charge  == 0 ) .or.
+     *              pstore(i)%code == keta ) then
                   if(x> xth) then
-                     pstore(i).fm.p(4) = pstore(i).mass
-                     pstore(i).fm.p(1:3) = 0.    ! put zero energy
+                     pstore(i)%fm%p(4) = pstore(i)%mass
+                     pstore(i)%fm%p(1:3) = 0.    ! put zero energy
                      modified = .true.
                   endif
                endif
             endif
          elseif( mode == 0 ) then
-c               do nothing
+!               do nothing
          else
             write(0,*) ' mode err=',mode, ' in csoftenPiK0'
             stop
@@ -329,25 +329,25 @@ c               do nothing
 
 
       subroutine csoftenPiK1(inciptcl, pstore, nin, nout, exist)
-c         inciptcl made a collision and generated nin particles in pstore
-c         particle.  information may be at CMS or Lab.
-c     If we want to  make the x-dist. softer,
-c      A) For Cosmos (air target),  we may use the Lab system
-c         (for large X, the distribution would be the same 
-c           as CMS)
+!         inciptcl made a collision and generated nin particles in pstore
+!         particle.  information may be at CMS or Lab.
+!     If we want to  make the x-dist. softer,
+!      A) For Cosmos (air target),  we may use the Lab system
+!         (for large X, the distribution would be the same 
+!           as CMS)
       implicit none
 #include  "Zcode.h"
 #include  "Zptcl.h"
 
-      record /ptcl/inciptcl  ! input. incident ptcl at collision
-c                  
+      type(ptcl):: inciptcl  ! input. incident ptcl at collision
+!                  
       integer,intent(in)::nin ! # of ptcls in pstore 
-      record /ptcl/pstore(*)  ! input/output.   ptcls to be softened.
+      type(ptcl):: pstore(*)  ! input/output.   ptcls to be softened.
                            !     Softened ones are put here
       integer,intent(out)::nout ! # of ptcls re-stored in pstore 
       integer,intent(out)::exist  ! # of particcls with X> Xth
-C ----------------------------------------------
-      record /ptcl/work(2)
+! ----------------------------------------------
+      type(ptcl):: work(2)
       logical  ok
       integer::maxi
       real(8)::maxE
@@ -364,41 +364,41 @@ C ----------------------------------------------
       centval =  crejK1(xcent)
 
 
-      E0 = inciptcl.fm.p(4) - inciptcl.mass
+      E0 = inciptcl%fm%p(4) - inciptcl%mass
       nout = nin
       exist = 0
       if( E0lab < E0th) return      !!!!!
       nc = nin
-c            if pi/K is incident, regards the highest one as leading
-c            and avoid to modify 
-      if(leadingPiK .and. (inciptcl.code == kpion .or.
-     *     inciptcl.code == kkaon ) ) then
-c              find max energy ptcl index and E; eta cannot be incident
-         call cgetmaxptcl(pstore, nc, inciptcl.code, inciptcl.charge,
+!            if pi/K is incident, regards the highest one as leading
+!            and avoid to modify 
+      if(leadingPiK .and. (inciptcl%code == kpion .or.
+     *     inciptcl%code == kkaon ) ) then
+!              find max energy ptcl index and E; eta cannot be incident
+         call cgetmaxptcl(pstore, nc, inciptcl%code, inciptcl%charge,
      *        maxi, maxE)
       else
          maxi = 0
       endif
 
       do i = 1, nin
-         x = (pstore(i).fm.p(4)-pstore(i).mass)/E0
+         x = (pstore(i)%fm%p(4)-pstore(i)%mass)/E0
          if( x > xth*xthl ) cycle
          if( abs(mode) == 3 ) then
             if( i /= maxi ) then
-c                softening
+!                softening
                if(x > xth/xthu) then
 !                  modify high X of pi/K/eta
-                  if(pstore(i).code == kpion .or.
-     *                 pstore(i).code == kkaon 
-     *                 .or.   pstore(i).code ==  keta ) then
+                  if(pstore(i)%code == kpion .or.
+     *                 pstore(i)%code == kkaon 
+     *                 .or.   pstore(i)%code ==  keta ) then
                      nw = 0
                      exist = exist + 1
 !                       judge to split this
 !!                     call cJudgeSplit(inciptcl, x,  split)
                      call rndc(u)
                      temp = crejK1(x)
-c                     split = u < 0.25*(temp/centval)
-c                     split = u < 0.125*(temp/centval)
+!                     split = u < 0.25*(temp/centval)
+!                     split = u < 0.125*(temp/centval)
                      split = u < k1u*(temp/centval)
                      if( .not. split ) cycle   
 
@@ -408,11 +408,11 @@ c                     split = u < 0.125*(temp/centval)
                      ! split;  if impossilbe, do nothing
                         nw = nw + 1
                         work(nw) = pstore(i)
-                        work(nw).fm.p(4) = E1 + work(nw).mass 
+                        work(nw)%fm%p(4) = E1 + work(nw)%mass 
                         call cae2p(work(nw)) ! adjust momentum
                         nw = nw + 1
                         work(nw) = pstore(i)
-                        work(nw).fm.p(4) = E2 + work(nw).mass 
+                        work(nw)%fm%p(4) = E2 + work(nw)%mass 
                         call cae2p(work(nw))
 !                       original one is replaced by E1
                         pstore(i) = work(1)
@@ -427,32 +427,32 @@ c                     split = u < 0.125*(temp/centval)
             endif
          elseif( mode == 1 ) then
             if( i /= maxi ) then
-c               discard all pi/K/eta with x>xth (except leanding)
-               if(pstore(i).code == kpion .or. pstore(i).code == kkaon 
-     *              .or.   pstore(i).code ==  keta ) then
+!               discard all pi/K/eta with x>xth (except leanding)
+               if(pstore(i)%code == kpion .or. pstore(i)%code == kkaon 
+     *              .or.   pstore(i)%code ==  keta ) then
                   if( x > xth ) then
-c                   to neglect, put mass as E
-                     pstore(i).fm.p(4) = pstore(i).mass
-                     pstore(i).fm.p(1:3) = 0.
+!                   to neglect, put mass as E
+                     pstore(i)%fm%p(4) = pstore(i)%mass
+                     pstore(i)%fm%p(1:3) = 0.
                      modified = .true.
                   endif
                endif
             endif
          elseif( mode == 2 ) then 
             if( i /= maxi) then
-c              discard only pi0/eta
-               if( ( pstore(i).code == kpion .and.
-     *              pstore(i).charge  == 0 ) .or.
-     *              pstore(i).code == keta ) then
+!              discard only pi0/eta
+               if( ( pstore(i)%code == kpion .and.
+     *              pstore(i)%charge  == 0 ) .or.
+     *              pstore(i)%code == keta ) then
                   if(x> xth) then
-                     pstore(i).fm.p(4) = pstore(i).mass
-                     pstore(i).fm.p(1:3) = 0.    ! put zero energy
+                     pstore(i)%fm%p(4) = pstore(i)%mass
+                     pstore(i)%fm%p(1:3) = 0.    ! put zero energy
                      modified = .true.
                   endif
                endif
             endif
          elseif( mode == 0 ) then
-c               do nothing
+!               do nothing
          else
             write(0,*) ' mode err=',mode, ' in csoftenPiK0'
             stop
@@ -467,7 +467,7 @@ c               do nothing
       implicit none
 #include  "Zcode.h"
 #include  "Zptcl.h"
-      record /ptcl/p   ! input, a high energy ptcl
+      type(ptcl):: p   ! input, a high energy ptcl
       real(8),intent(out):: E1  ! split ptcl energy KE
       real(8),intent(out):: E2  ! split ptcl
       integer,intent(out):: icon ! 0--> split ok, 1--> no split
@@ -481,8 +481,8 @@ c               do nothing
       do while(.not. ok)
          call rndc(u)
          u = u*(1.-xth) + xth
-         E1 = u*( p.fm.p(4) - p.mass)
-         E2 = (p.fm.p(4) -p.mass) - E1
+         E1 = u*( p%fm%p(4) - p%mass)
+         E2 = (p%fm%p(4) -p%mass) - E1
 !         if(E1 > p.mass .and.
 !     *      E2 > p.mass ) then
             ok = .true.
@@ -498,45 +498,45 @@ c               do nothing
       end subroutine csplitMeson
  
       subroutine  cae2p( pc )
-c             adjust mpmentum by refering to changed E
-c         keep the Pt same, if possible
+!             adjust mpmentum by refering to changed E
+!         keep the Pt same, if possible
       implicit none
 #include  "Zcode.h"
 #include  "Zptcl.h"
 
 
-      record /ptcl/ pc
+      type(ptcl):: pc
       
       real(8):: E,  P2, cf
 
-      E = pc.fm.p(4)
-c      
-c         Pt^2 + Pz^2 +m^2= E^2
-c         so new Pz =sqrt( E^2-Pt^2-m^2) 
-c          the sign is the same as original one
-      P2 =E**2- ( pc.fm.p(1)**2  + pc.fm.p(2)**2 + pc.mass**2)
-      if( P2 > pc.mass**2  ) then
-         pc.fm.p(3) =  sign(sqrt(P2), pc.fm.p(3))
+      E = pc%fm%p(4)
+!      
+!         Pt^2 + Pz^2 +m^2= E^2
+!         so new Pz =sqrt( E^2-Pt^2-m^2) 
+!          the sign is the same as original one
+      P2 =E**2- ( pc%fm%p(1)**2  + pc%fm%p(2)**2 + pc%mass**2)
+      if( P2 > pc%mass**2  ) then
+         pc%fm%p(3) =  sign(sqrt(P2), pc%fm%p(3))
       else
-c         keep the direction and shirnk the magnitude of p
-         P2 = pc.fm.p(1)**2  + pc.fm.p(2)**2  + pc.fm.p(3)**2
-         if( E <= pc.mass .or. P2 == 0. ) then
-            pc.fm.p(1:3) = 0.         
+!         keep the direction and shirnk the magnitude of p
+         P2 = pc%fm%p(1)**2  + pc%fm%p(2)**2  + pc%fm%p(3)**2
+         if( E <= pc%mass .or. P2 == 0. ) then
+            pc%fm%p(1:3) = 0.         
          else
-            cf = sqrt( (E**2 - pc.mass**2) / P2 )
-            pc.fm.p(1:3) = pc.fm.p(1:3)*cf
+            cf = sqrt( (E**2 - pc%mass**2) / P2 )
+            pc%fm%p(1:3) = pc%fm%p(1:3)*cf
          endif
       endif
       end  subroutine cae2p 
       subroutine cgetMaxptcl(pstore, nin,  pcode, pcharge, maxi, maxE)
-c        get max energy ptcl with the same code / charge as incident
-c        if meson is incident, most probably, it is leading.
+!        get max energy ptcl with the same code / charge as incident
+!        if meson is incident, most probably, it is leading.
       implicit none
 #include  "Zcode.h"
 #include  "Zptcl.h"
 
       integer,intent(in):: nin ! # of ptcls in pstore
-      record /ptcl/ pstore(nin) 
+      type(ptcl):: pstore(nin) 
       
       integer(2),intent(in):: pcode    ! incident code
       integer(2),intent(in):: pcharge  ! //       charge
@@ -550,40 +550,40 @@ c        if meson is incident, most probably, it is leading.
       maxi = 0
       maxE = 0.
       do  i = 1,  nin
-         if( pstore(i).code /=  pcode ) cycle
-         if( pstore(i).charge /= pcharge ) cycle
-         if( maxE < pstore(i).fm.p(4) ) then
-            maxE =  pstore(i).fm.p(4) 
+         if( pstore(i)%code /=  pcode ) cycle
+         if( pstore(i)%charge /= pcharge ) cycle
+         if( maxE < pstore(i)%fm%p(4) ) then
+            maxE =  pstore(i)%fm%p(4) 
             maxi = i
          endif
       enddo
       end subroutine cgetMaxptcl
 
       subroutine csoftenFE(inci, fwbwin, a, nin, nout)
-c       front end of softening when it is to be  done at CMS
-c         x is defined simply by E/E0, 
+!       front end of softening when it is to be  done at CMS
+!         x is defined simply by E/E0, 
       implicit none 
 #include "Zptcl.h"      
-      record /ptcl/ inci  ! incident ptcl (in cms); symmetric case 
+      type(ptcl):: inci  ! incident ptcl (in cms); symmetric case 
       integer,intent(in):: fwbwin  ! modification is applied to
                                  ! 1--> forward only 2--> backword only
                                  ! 3--> both ; However, 1 is used when
                      ! Cosmos output (in cms) is the target, independently of
                      ! fwbw.  
-      record /ptcl/ a(*)  ! array containing ptcl info.
+      type(ptcl):: a(*)  ! array containing ptcl info.
       integer,intent(in)::nin ! # of ptcls in w
       integer,intent(out)::nout ! # of ptcls put in w after modification
 
-      record /ptcl/ w1(half)  ! working array
-      record /ptcl/ w2(half)  ! working array
+      type(ptcl):: w1(half)  ! working array
+      type(ptcl):: w2(half)  ! working array
 
       integer::i, nc1, nc2, ncout1, ncout2
 
-c       do modification  extract Pz>0  and Pz<0
+!       do modification  extract Pz>0  and Pz<0
       nc1 = 0
       nc2 = 0
       do i = 1, nin
-         if(a(i).fm.p(3) > 0.) then
+         if(a(i)%fm%p(3) > 0.) then
             nc1 = nc1 + 1
             w1(nc1) = a(i)
          else
@@ -652,7 +652,7 @@ c       do modification  extract Pz>0  and Pz<0
           end select
        enddo
        end       subroutine creadSoftenPara
-c      *************
+!      *************
        subroutine  cwriteSoftenPara(io)
        implicit none
        integer,intent(in):: io
@@ -683,13 +683,13 @@ c      *************
           if(sep(2:10) == '---------') exit
        enddo
        end  subroutine cskipsep
-c        ************************* real*8 data
+!        ************************* real*8 data
        subroutine creadParaR(vvalue, x)
         implicit none
         integer io
         character*(*) vvalue
         real*8 x
-c        read(vvalue, *)   x, x
+!        read(vvalue, *)   x, x
         read(vvalue, *)   x
         end       subroutine creadParaR
        subroutine creadParaR2(vvalue, x, n)
@@ -701,35 +701,35 @@ c        read(vvalue, *)   x, x
         read(vvalue, *)   x
         end       subroutine creadParaR2
 
-c     ************************* complex data
+!     ************************* complex data
       subroutine creadParaCx(vvalue, c)
       implicit none
       character*(*) vvalue
       complex*8 c
       read( vvalue, *)   c
       end      subroutine creadParaCx
-c     ************************ integer data
+!     ************************ integer data
       subroutine creadParaI(vvalue, i)
       implicit none
       character*(*) vvalue
       integer i
       read(vvalue, *)   i
       end      subroutine creadParaI
-c        ************************* character data
+!        ************************* character data
       subroutine creadParaC(vvalue, cha)
       implicit none
       character*(*) vvalue
       character*(*) cha
       read(vvalue, *)  cha
       end      subroutine creadParaC
-c        ***************************** logical data
+!        ***************************** logical data
       subroutine creadParaL(vvalue, logi)
       implicit none
       character*(*) vvalue
       logical logi
       read(vvalue, *)  logi
       end           subroutine creadParaL
-c        ---------------------------------------------
+!        ---------------------------------------------
       subroutine cwriteParaR(io, vname, x)
       implicit none
       integer io
@@ -810,7 +810,7 @@ c        ---------------------------------------------
       end      function ck1u
 
       function cgetParmN( io,  vname, vv ) result(ans)
-c          get parameter variable name and given value(s)  from io
+!          get parameter variable name and given value(s)  from io
        implicit none
        integer io
        character*(*)  vname, vv  ! output
