@@ -1,7 +1,7 @@
       real*8  azmmin, azmmax, zen1, zen2, rigc, E, zen, ratio
       logical degree
       integer  cosfactor
-      record /component/compx
+      type (component)::compx
       common/ZgetST/compx, zen1, zen2, azmmin, azmmax, rigc, E,
      *     zen,  ratio, degree, cosfactor
 
