@@ -2,8 +2,8 @@
       implicit none
 #include "Zptcl.h"
 #include "Zprimary.h"
-c          primary flux at E       
-      record /component/comp
+!          primary flux at E       
+      type (component)::comp
       integer i1, i2
       real*8 ans
 
@@ -13,16 +13,16 @@ c          primary flux at E
       sum = 0.
 
       do i = i1, i2
-         if(comp.cut .ne. 0.) then
-            if(comp.emin .le. comp.energy(i)) then
-               sum =  comp.norm_inte(i)
+         if(comp%cut .ne. 0.) then
+            if(comp%emin .le. comp%energy(i)) then
+               sum =  comp%norm_inte(i)
                goto 100
             endif
          else
-            sum = comp.norm_inte(i)
+            sum = comp%norm_inte(i)
             goto 100
          endif
       enddo
  100  continue
-      ans = sum * comp.inte_value
+      ans = sum * comp%inte_value
       end
