@@ -41,10 +41,14 @@
          if(Trace .gt. 0) then
             call outtrace(j, w, ntp)
          endif
-         if(outresul1 == 0 ) then
-            call outresul(w, ntp)
-         elseif(outresul1 == 1 ) then
+         if(outresul == 0 ) then
+            call outresulA(w, ntp)
+         elseif(outresul == 1 ) then
             call outresulB(w, ntp)
+         elseif(outresul == 2 ) then
+            call outresulC(w, ntp)
+         elseif(outresul == 3 ) then
+            call outresulX(w, ntp)
          endif
       enddo
       write(0,*) 
@@ -93,7 +97,7 @@
       write(0,*) ' cos* min  max=', wzmin, wzmax
       call cqUhookr(3, trackl)
       call cqUhooki(1, outzero)
-      call cqUhooki(2, outresul1)
+      call cqUhooki(2, outresul)
 !       make projectile going +z
       call cqUhookc(1, input) 
       if(input(1:4) .eq. "file") then
@@ -140,13 +144,9 @@
 #else
          write(0,*) 'to use qgsjet1,  define it  in Zintmodel.h'
 #endif
-      elseif(index (IntModel, 'sibyll') .ne. 0 )  then
-!cc  #ifdef  SIBYLL
-         call csibyllinit
-         ActiveMdl = 'sibyll'
-!c #else
-!cc        write(0,*) 'to use sibyll, define it in Zintmodel.h'
-!cc #endif
+!      elseif(index (IntModel, 'sibyll') .ne. 0 )  then
+!         call csibyllinit
+!         ActiveMdl = 'sibyll'
       else
          call cintModels('gencol')
          call cfixModel( plab )
@@ -536,7 +536,7 @@
       call cputGencolCMS(Zcmsp) 
       end
 !     ************************
-      subroutine outresul(a, ntp)
+      subroutine outresulA(a, ntp)
       implicit none
 #include  "Zptcl.h"
 #include  "Zcode.h"
@@ -559,32 +559,21 @@
 
       do j = 1, ntp
          i = indx(j)
-!         p= sqrt( a(i).fm.p(1)**2 + a(i).fm.p(2)**2
-!     *        +      a(i).fm.p(3)**2 )
          p = sqrt(
      *  dot_product( a(i)%fm%p(1:3), a(i)%fm%p(1:3)) )
          wx(1:3)= a(i)%fm%p(1:3)/p
-!         wx = a(i).fm.p(1)/p               
-!         wy = a(i).fm.p(2)/p               
-!         wz = a(i).fm.p(3)/p               
          if(xyz .eq. 0) then
             write(*,
      *     '(i3,i5,i4,1p, g14.5,0p, 3f17.13, i8)')
      *        a(i)%code, a(i)%subcode, a(i)%charge,
      *        a(i)%fm%p(4)-a(i)%mass, wx(1:3), j
 
-!            write(*,
-!     *     '(i3,i5,i4,1p, g14.5,0p, 3f17.13, 1p,3g12.4, i8)')
-!     *        a(i).code, a(i).subcode, a(i).charge,
-!     *        a(i).fm.p(4)-a(i).mass, wx(1:3), 
-!     *        a(i).fm.p(1:3),   j
 
          else
             write(*,'(i3,i5,i4,g14.5,1p3E11.3,0p3f17.13, i8)')
      *        a(i)%code, a(i)%subcode, a(i)%charge,
-!     *        a(i).fm.p(4)-a(i).mass, xpos, ypos, zpos, 
      *        a(i)%fm%p(4)-a(i)%mass, xpos(1:3), wx(1:3), j
-!     *        wx, wy, wz, j
+
          endif
       enddo
       if(ntp .gt. 0 .or. outzero .eq. 1) then
@@ -596,6 +585,7 @@
       implicit none
 #include  "Zptcl.h"
 #include  "Zcode.h"
+#include "Zmass.h"
 #include  "Zevhnv.h"
 #include  "Zevhnp.h"
 #include  "Zmanagerp.h"
@@ -607,11 +597,13 @@
 !
       integer  ntp
       integer j
-      integer tZ, tA
-      real*8  xs
-!     
+      integer tZ, tA, L
+      real*8  xs, SIGbdif, xsair
+      real*8   roots
+      
       tA = tgmnum
       tZ =  tg%charge
+
       if(pj%code == kmuon ) then
 !         sepcial treatment
          call epGencolByMuon(plab, tA, tZ,  a, ntp)
@@ -630,16 +622,17 @@
          elseif(ActiveMdl .eq. 'epos' ) then
             call ceposIniOneEvent(plab, tg, xs)
          endif
-
+!!!!!!!         
+!     you may include  ToPrintXS.f here to print out E vs XS for Sibyll
+ !!!!!!!!
 !           generate event
          if(ActiveMdl .eq. 'qgsjet1') then
 #ifdef QGSJET1
             call qgs01event(plab, tA, tZ, a, ntp)
 #endif
-         elseif(ActiveMdl .eq. 'sibyll') then
-!cc #ifdef SIBYLL
-            call csibyllevent(plab, tA, tZ, a, ntp)
-!cc #endif
+!!         elseif(ActiveMdl .eq. 'sibyll') then
+!!!
+!!            call csibyllevent(plab, tA, tZ, a, ntp)
          else
             call chAcol(plab, tA, tZ,  a, ntp)
          endif
@@ -883,9 +876,14 @@
       type (ptcl):: a(ntp)
       integer  i, j
 
+      integer:: npp
+      
+
+      
       real*8  p, wx, wy, wz, pt, y, eta
       integer npzm, npzp, Ncht, Nchpzm, Nchpzp
-      integer nw, diffcode(20) 
+      integer nw, diffcode(20)
+      real(8):: Xfpz, Xfke
 !//////////////
       type (ptcl):: inlab
       real(8):: ylab, etalab
@@ -900,10 +898,9 @@
       Nchpzm = 0
       Nchpzp = 0
 
+      
       do j = 1, ntp
          i = indx(j)
-!         pt = sqrt( a(i).fm.p(1)**2 + a(i).fm.p(2)**2)
-!         p= sqrt( pt**2  +    a(i).fm.p(3)**2 )
          if( a(i)%fm%p(3) .gt. 0.) then
             npzp = npzp + 1
             if(a(i)%charge .ne. 0) then
@@ -917,48 +914,25 @@
          endif
       enddo
       Ncht = Nchpzm + Nchpzp
-      call getDiffCode(nw, diffcode)
-      write(*,'("h ",i3, 7i6)' ) 
-     * diffcode(1), ntp, npzm, npzp, Ncht, Nchpzm, Nchpzp, nthev
+!      ntpp = 0   !  ?
 
       do j = 1, ntp
          i = indx(j)
          pt = sqrt( a(i)%fm%p(1)**2 + a(i)%fm%p(2)**2)
-         p= sqrt( pt**2  +    a(i).fm.p(3)**2 )
-!
-!         wx = a(i).fm.p(1)/p               
-!         wy = a(i).fm.p(2)/p               
-         wz = a(i).fm.p(3)/p               
-!         if(xyz .eq. 0) then
-!            write(*,'(3i3,g14.5,3f17.13, i5)')
-!     *        a(i).code, a(i).subcode, a(i).charge,
-!     *        a(i).fm.p(4)-a(i).mass, wx, wy, wz, j
-!         else
-!            write(*,'(3i3,g14.5,1p3E11.3,0p3f17.13, i5)')
-!     *        a(i).code, a(i).subcode, a(i).charge,
-!     *        a(i).fm.p(4)-a(i).mass, xpos, ypos, zpos, 
-!     *        wx, wy, wz, j
-!         
-!         endif
+         p= sqrt( pt**2  +    a(i)%fm%p(3)**2 )
+         Xfke = ( a(i)%fm%p(4)-a(i)%mass) /( pj%fm%p(4)- pj%mass)
+         Xfpz =  a(i)%fm%p(3) / pj%fm%p(3)
+         
+         wz = a(i)%fm%p(3)/p               
          call cyeta(a(i),  y, eta)
-!////////////
-!c           boost to target rest system
-         call cbst1(1, tg, a(i), inlab)
-         call cyeta(inlab,  ylab, etalab)
-!///////////////
-!/////////////
-!         call clorez(gc, a(i), pl)
-!         write(*,'(2i4, 1p, g13.4, 0p, f10.4, 1p,6g13.4)')
-!     *   a(i).code,  a(i).charge,  pt,  eta, pl.fm.p(4)-pl.mass,
-!     *     a(i).fm.p(1:4)
-!//////////////////
-!         write(*,'(3i4, 1p, g13.4, 0p, f10.4,1p, 6g13.4)')
-!     *   a(i)%code,  a(i)%subcode,  a(i)%charge,
-!     *     pt, y,  eta, a(i)%fm%p(4)-a(i)%mass,  a(i)%fm%p(3),
+         write(*,'(3i4, 1p, 7g13.4)')
+     *         a(i)%code,  a(i)%subcode,  a(i)%charge,
+     *        pt, y,  eta, a(i)%fm%p(4)-a(i)%mass,  a(i)%fm%p(3),
+     *        Xfke, Xfpz           
 !     *     ylab, etalab
-         write(*,'(3i4, 1p, 3g13.4)')
-     *   a(i)%code,  a(i)%subcode,  a(i)%charge,
-     *      a(i)%fm%p(4)-a(i)%mass,    a(i)%fm%p(3), wz
+!         write(*,'(3i4, 1p, 3g13.4)')
+!     *   a(i)%code,  a(i)%subcode,  a(i)%charge,
+!     *    a(i)%fm%p(4)-a(i)%mass,    a(i)%fm%p(3), wz
 
          
       enddo
@@ -966,3 +940,137 @@
          write(*, *) 
       endif
       end
+      subroutine outresulC(a, ntp)
+      implicit none
+#include  "Zptcl.h"
+#include  "Zcode.h"
+#include  "Zevhnp.h"
+#include  "Zevhnv.h"
+#include  "Zmass.h"
+#include  "Zmanagerp.h"
+#include  "Zmanager.h"
+#include  "Ztrackp.h"
+      integer,save:: nthev=0
+      include  "Zprivate.h"
+! general process information; only for dpmjet3
+      INTEGER IPROCE,IDNODF,IDIFR1,IDIFR2,IDDPOM,IPRON
+      COMMON /POPRCS/ IPROCE,IDNODF,IDIFR1,IDIFR2,IDDPOM,IPRON(15,4)
+!      IPROCE
+!             1 non-diffractive inelastic
+!             2 elestic 
+!             3 quasi elestic vector meson prod. (photon)
+!             4 central diffraction
+!             5 single diff. ptcl 1
+!             6 //           ptcl 2
+!             7 double diff. 
+!             8 direct photo-hadron
+! For moore detail, see manual in Documents/CosmicRays/phojetShort.pdf
+!               say, IDIFR1 classifies IPROCE=5
+
+      integer ntp
+      type (ptcl):: a(ntp)
+      integer  i, j, icon
+
+      
+      integer:: npp
+      
+      real*8  p, wx, wy, wz, pt, y, eta
+      integer npzm, npzp, Ncht, Nchpzm, Nchpzp
+      integer nw, diffcode(20)
+      real(8):: Xfpz, Xfke
+!//////////////
+      type (ptcl):: restN
+      type (ptcl):: cmptcl
+      type (fmom):: gc
+      real(8):: s, rootsh, xf, xflab, xfmax
+      real(8):: Esmax, Pszmax, Pzmax, Ebypzmax, Esbyrootsh
+      real(8):: ys, etas, Es, Elab, pabs, cost, teta
+!/////////////
+      nthev=nthev+1
+
+
+      call cmkptc(6, -1, 1, restN)
+      restN%fm%p(1:3)=(/0.,0.,0./)
+      restN%fm%p(4) =  restN%mass
+      call cgetcm(pj, restN, gc, icon)
+      s =( restN%mass + pj%fm%p(4) ) *2 * restN%mass
+      rootsh = sqrt(s)/2
+      Esmax=rootsh - pj%mass
+      Pszmax=sqrt( Esmax**2 - maspic**2 )    ! pion case
+      Pzmax = gc%p(4)*Pszmax + gc%p(3)* Esmax !
+
+      do j = 1, ntp
+         call cbst0(j, gc, a(j), cmptcl) ! j==1  must be called.
+         call cyeta(cmptcl,  ys, etas)
+         call cyeta(a(j), y, eta)
+
+         Elab = a(j)%fm%p(4)
+         Es = cmptcl%fm%p(4)
+         xf = cmptcl%fm%p(3)/rootsh
+         xflab = a(j)%fm%p(3)/Pzmax
+         pt =sqrt( a(j)%fm%p(1)**2 + a(j)%fm%p(2)**2 )
+         pabs = sqrt( pt**2 + a(j)%fm%p(3)**2 )
+         cost = a(j)%fm%p(3)/pabs
+         teta = acos(cost)
+         write(*, '(2i4, 1p, 9g14.4)')
+     *     a(j)%code,  a(j)%charge, etas, Es, xf, eta, Elab,
+     *     xflab,  cost, teta, pt
+
+      enddo
+      if(ntp .gt. 0 .or. outzero .eq. 1) then
+         write(*, *) 
+      endif
+      end
+
+
+      subroutine outresulX(a, ntp)
+      implicit none
+#include  "Zptcl.h"
+#include  "Zcode.h"
+#include  "Zevhnp.h"
+#include  "Zevhnv.h"
+#include  "Zmass.h"
+#include  "Zmanagerp.h"
+#include  "Zmanager.h"
+#include  "Ztrackp.h"
+      include  "Zprivate.h"
+
+      integer ntp
+      type (ptcl):: a(ntp)
+      integer  i, j
+      real*8  p, mass2, p2
+      real*8  wx(3)
+      integer nw, difcode(20)
+
+!      call getDiffCode(nw, dffcode)
+!!!
+      call csibylGetDiffCode(nw, difcode)
+!      write(*,'("h ",i3, 7i6)' )
+!     * difcode(1),ntp, npzm, npzp, Ncht, Nchpzm, Nchpzp, nthev
+!      
+!      do i = 1, nw
+!         write(*,'(a, 3i10)')
+!     *         'dif ', i, difcode(i), ntp
+!      enddo
+      write(*,*) 'dif ', nw, difcode(1:nw)
+!!!!!!      
+      do i = 1, ntp
+         p2 =  dot_product(a(i)%fm%p(1:3), a(i)%fm%p(1:3) )
+         p = sqrt(p2)
+!     mass2= a(i)%fm%p(4)**2 - p2
+         mass2= (a(i)%fm%p(4)- p)*(a(i)%fm%p(4)+ p)
+!         if( a(i)%code  /= 1 .and.  
+!     *        (  abs(a(i)%mass/sqrt(mass2) -1.) > 0.01  )
+!     *           .or.
+!     *        a(i)%code == 0 .and.
+!     *        (  abs( a(i)%mass-sqrt(mass2) ) > 0.03  ) ) then       
+!!!            write(*,
+!!!     *     '(i3,i5,i4,1p, 6g22.14)')
+!!!     *        a(i)%code, a(i)%subcode, a(i)%charge,
+!!!     *           a(i)%fm%p(:), a(i)%mass, sqrt(mass2)
+!         endif
+      enddo
+      if(ntp .gt. 0 .or. outzero .eq. 1) then
+         write(*, *) 
+      endif
+      end
