@@ -1,16 +1,16 @@
-c          lat, long, horizontal, vertical, def. angle
-c
+!          lat, long, horizontal, vertical, def. angle
+!
          program Geomag
          implicit none
 
 #include  "Zcoord.h"
 #include  "Zmagfield.h"
          real*8 year, lat, long, h
-         record /coord/ llh
-         record /magfield/ b, hva
+         type (coord):: llh
+         type (magfield):: b, hva
          integer icon, igrf
          real*8  tand
-c
+!
          write(*,*)
      *  'Enter year(1996.5) lat(-90~90) long(-180~180)  height(0)'
          read(*, *) year, lat, long, h
@@ -28,16 +28,16 @@ c
 
          call cgeomag(year, llh, b, icon)
          write(*,*) ' icon=',icon
-         write(*,*) ' ned=', b.n, b.e, b.d
+         write(*,*) ' ned=', b%n, b%e, b%d
          call cned2hva(b, hva)
-         tand = atan( hva.v/hva.h) * 180./3.141592
+         tand = atan( hva%v/hva%h) * 180./3.141592
          call ctransMagTo('xyz', llh, b, b)
-         write(*,*) ' x=',b.x, ' y=', b.y, ' z=', b.z
+         write(*,*) ' x=',b%x, ' y=', b%y, ' z=', b%z
          write(*, *)
 #ifdef  UNIONMAP
-     *         sngl(hva.h), sngl(hva.v), sngl(hva.a)
+     *         sngl(hva%h), sngl(hva%v), sngl(hva%a)
 #else
-     *         sngl(hva.x), sngl(hva.y), sngl(hva.z)
+     *         sngl(hva%x), sngl(hva%y), sngl(hva%z)
 #endif
          write(*,*) ' fukaku =', tand, ' deg' 
          call cprintMagF(b)
