@@ -1,5 +1,9 @@
 #ifndef Zcondc_
 #define  Zcondc_
+!** MYEFIELD is not used now (Dec.3,2019).  Description below
+! is obso.  To use cmyEfield.f, try  UseSpecIntF.sh
+!  Effect of HowEfield is the same. 
+!
 !  define MYEFIELD  if Electric field is to be supplied 
 !  by the user using cmyEfield.f of which template is
 !  in UserHook/.  The user may copy it to the users
@@ -12,7 +16,7 @@
 !  without using this but by giving HowEfield=1 in the
 !  namelist parameter.  Then simple electric
 !  field can be specified (together with other parameters)
-#undef MYEFIELD 
+! #undef MYEFIELD 
 !!! define MYEFIELD
 !   dpmjet cannot be used on NEXTSTEP, so
 !   you have to make the next 0. 
