@@ -1,5 +1,5 @@
-c            hadronic collision parameters 
-c	(->  ---------------------------------------------
+!            hadronic collision parameters 
+!	(->  ---------------------------------------------
 
         character*64  IntModel !1 Interaction model description. Usage was changed from v6.0. 
                       !    One may list  code name and upper energy bound  for the code.\newline
@@ -77,11 +77,11 @@ c	(->  ---------------------------------------------
                         !   effective s. s'(GeV**2)=s - 4.63.  See also Kpicns.
         real*8  Kpicns  !2  See Kpilog. 0.077
         real*8  Elund   !2   obsolete (from v6.0)
-c                  old def
+!                  old def
         real*8  Elund2  !2  obsolete (from v6.0)
-c              old def
+!              old def
          real*8 Elund3   !2 obsolete  (from v6.0).
-	 real*8  Efermi  !2  If Kinetic E $<$ Efermi, Fermi Momentum is considered for 
+          real*8  Efermi  !2  If Kinetic E $<$ Efermi, Fermi Momentum is considered for 
                          ! Nucleus target.
          integer:: DoNPadjust !2 0(Default):  0--> original is used
                     ! 1--> do adustement of  # of n,p  for phits model
@@ -89,10 +89,19 @@ c              old def
          integer:: dpmRareDecay !2 1(Default):  Rare ptcls in dpmjet3 is
                      ! forced to decay. (see cdpmRareDecay in cdpmjet3.f)
                      ! 0--> not decayed
-c	<-)     -----------------------------
-c            next are not input parameters.
+         integer:: K0sSemiLD !2  12(Default).  
+                !  semileptonic decay channel of K0s is
+                !  1) pi+e + nue   B.R 7x10^-4
+                !  2) pi+mu+ numu  B.R 6.4x10^-4
+                ! if 0, these are neglected.
+                ! if 1, only 1) is taken into account
+                ! if 2, only 2) is //
+                ! if 12, both are taken into account.  
+!	<-)     -----------------------------
+!            next are not input parameters.
         integer nmdls
-        parameter (nmdls = 12)
+!        parameter (nmdls = 12)
+        parameter (nmdls = 13)
         character*16 RegMdls(nmdls)
         real*8 smallxs, largexs
         parameter (smallxs=1.d-10, largexs=1.d10)
@@ -100,7 +109,7 @@ c            next are not input parameters.
         common /Zevhnp/ Cepic0, Cekaon, Ceneuc, Mudirp, Kpilog, Eta2Pi0,
      *         Kpicns,  Efermi, Elund, Elund2, Elund3, SucPw, MulLow, 
      *         LundPara(10), SucInt, DoNPadjust, dpmRareDecay,
-     *         TotXSopt, SxAbySxpOpt
+     *         TotXSopt, SxAbySxpOpt, K0sSemiLD
 !!     *         LundPara(10), SucInt
         common /Zevhnc/RegMdls, InclusiveFile, IntModel, XsecModel
 
